{
    "$graph": [
        {
            "class": "ExpressionTool",
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                }
            ],
            "id": "#fastqc-results-trigger.cwl",
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "loadContents": true
                    },
                    "id": "#fastqc-results-trigger.cwl/fastqc_results_trigger/summary_file"
                }
            ],
            "expression": "${\n  var criteria_array = inputs.summary_file.contents.match(/.*Per base sequence quality.*|.*Per sequence quality scores.*|.*Overrepresented sequences.*|.*Adapter Content.*/g);\n  if (criteria_array.length > 0){\n    if (criteria_array.toString().match(/FAIL/g) != null){\n      return { \"trigger\": true };\n    } else {\n      return { \"trigger\": false };\n    }\n  } else {\n    return { \"trigger\": true };\n  }\n}",
            "outputs": [
                {
                    "type": "boolean",
                    "id": "#fastqc-results-trigger.cwl/fastqc_results_trigger/trigger"
                }
            ]
        },
        {
            "class": "ExpressionTool",
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "string",
                    "id": "#get-file-by-name.cwl/basename_regex"
                },
                {
                    "type": [
                        "Directory",
                        {
                            "type": "array",
                            "items": "File"
                        }
                    ],
                    "id": "#get-file-by-name.cwl/input_files"
                }
            ],
            "outputs": [
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "id": "#get-file-by-name.cwl/selected_file"
                }
            ],
            "expression": "${\n  var patt = new RegExp(inputs.basename_regex);\n  var files = [];\n\n  if (inputs.input_files.class == \"Directory\"){\n    files = inputs.input_files.listing;\n  } else {\n    files = inputs.input_files;\n  }\n\n  for (var i = 0; i < files.length; i++ ){\n    if ( patt.test(files[i].location.split('/').slice(-1)[0]) ){\n      return { \"selected_file\": files[i] }\n    }\n  }\n\n  return { \"selected_file\": null };\n}\n",
            "doc": "Returns file the first file from input File[], that match input regex expression",
            "id": "#get-file-by-name.cwl"
        },
        {
            "class": "Workflow",
            "requirements": [
                {
                    "class": "StepInputExpressionRequirement"
                },
                {
                    "class": "InlineJavascriptRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "label": "Input BAM file",
                    "doc": "Input BAM file, sorted by coordinates",
                    "id": "#bam-bedgraph-bigwig.cwl/bam_file"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "label": "bedGraph output filename",
                    "doc": "Output filename for generated bedGraph",
                    "id": "#bam-bedgraph-bigwig.cwl/bedgraph_filename"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "label": "bigWig output filename",
                    "doc": "Output filename for generated bigWig",
                    "id": "#bam-bedgraph-bigwig.cwl/bigwig_filename"
                },
                {
                    "type": "File",
                    "label": "Chromosome length file",
                    "doc": "Tab delimited chromosome length file: <chromName><TAB><chromSize>",
                    "id": "#bam-bedgraph-bigwig.cwl/chrom_length_file"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "label": "Enable dUTP",
                    "doc": "Change strand af the mate read, so both reads come from the same strand",
                    "id": "#bam-bedgraph-bigwig.cwl/dutp"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "label": "Fixed fragment size",
                    "doc": "Set fixed fragment size for genome coverage calculation",
                    "id": "#bam-bedgraph-bigwig.cwl/fragment_size"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "label": "Mapped reads number",
                    "doc": "Parameter to calculate scale as 1000000/mapped_reads_number. Ignored by bedtools-genomecov.cwl in\nbam_to_bedgraph step if scale is provided\n",
                    "id": "#bam-bedgraph-bigwig.cwl/mapped_reads_number"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "label": "Enable paired-end genome coverage calculation",
                    "doc": "Enable paired-end genome coverage calculation",
                    "id": "#bam-bedgraph-bigwig.cwl/pairchip"
                },
                {
                    "type": [
                        "null",
                        "float"
                    ],
                    "label": "Genome coverage scaling coefficient",
                    "doc": "Coefficient to scale the genome coverage by a constant factor",
                    "id": "#bam-bedgraph-bigwig.cwl/scale"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "label": "Split reads by 'N' and 'D'",
                    "doc": "Calculate genome coverage for each part of the splitted by 'N' and 'D' read",
                    "id": "#bam-bedgraph-bigwig.cwl/split"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "label": "Enable strand specific genome coverage calculation",
                    "doc": "Calculate genome coverage of intervals from a specific strand",
                    "id": "#bam-bedgraph-bigwig.cwl/strand"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputSource": "#bam-bedgraph-bigwig.cwl/sort_bedgraph/sorted_file",
                    "label": "bedGraph output file",
                    "doc": "bedGraph output file",
                    "id": "#bam-bedgraph-bigwig.cwl/bedgraph_file"
                },
                {
                    "type": "File",
                    "outputSource": "#bam-bedgraph-bigwig.cwl/sorted_bedgraph_to_bigwig/bigwig_file",
                    "label": "bigWig output file",
                    "doc": "bigWig output file",
                    "id": "#bam-bedgraph-bigwig.cwl/bigwig_file"
                }
            ],
            "steps": [
                {
                    "run": "#bedtools-genomecov.cwl",
                    "in": [
                        {
                            "default": "-bg",
                            "id": "#bam-bedgraph-bigwig.cwl/bam_to_bedgraph/depth"
                        },
                        {
                            "source": "#bam-bedgraph-bigwig.cwl/dutp",
                            "id": "#bam-bedgraph-bigwig.cwl/bam_to_bedgraph/du"
                        },
                        {
                            "source": "#bam-bedgraph-bigwig.cwl/fragment_size",
                            "id": "#bam-bedgraph-bigwig.cwl/bam_to_bedgraph/fragment_size"
                        },
                        {
                            "source": "#bam-bedgraph-bigwig.cwl/bam_file",
                            "id": "#bam-bedgraph-bigwig.cwl/bam_to_bedgraph/input_file"
                        },
                        {
                            "source": "#bam-bedgraph-bigwig.cwl/mapped_reads_number",
                            "id": "#bam-bedgraph-bigwig.cwl/bam_to_bedgraph/mapped_reads_number"
                        },
                        {
                            "source": "#bam-bedgraph-bigwig.cwl/bedgraph_filename",
                            "id": "#bam-bedgraph-bigwig.cwl/bam_to_bedgraph/output_filename"
                        },
                        {
                            "source": "#bam-bedgraph-bigwig.cwl/pairchip",
                            "id": "#bam-bedgraph-bigwig.cwl/bam_to_bedgraph/pairchip"
                        },
                        {
                            "source": "#bam-bedgraph-bigwig.cwl/scale",
                            "id": "#bam-bedgraph-bigwig.cwl/bam_to_bedgraph/scale"
                        },
                        {
                            "source": "#bam-bedgraph-bigwig.cwl/split",
                            "valueFrom": "${\n  if (self == null){\n    return true;\n  } else {\n    return self;\n  }\n}\n",
                            "id": "#bam-bedgraph-bigwig.cwl/bam_to_bedgraph/split"
                        },
                        {
                            "source": "#bam-bedgraph-bigwig.cwl/strand",
                            "id": "#bam-bedgraph-bigwig.cwl/bam_to_bedgraph/strand"
                        }
                    ],
                    "out": [
                        "#bam-bedgraph-bigwig.cwl/bam_to_bedgraph/genome_coverage_file"
                    ],
                    "id": "#bam-bedgraph-bigwig.cwl/bam_to_bedgraph"
                },
                {
                    "run": "#linux-sort.cwl",
                    "in": [
                        {
                            "default": [
                                "1,1",
                                "2,2n"
                            ],
                            "id": "#bam-bedgraph-bigwig.cwl/sort_bedgraph/key"
                        },
                        {
                            "source": "#bam-bedgraph-bigwig.cwl/bam_to_bedgraph/genome_coverage_file",
                            "id": "#bam-bedgraph-bigwig.cwl/sort_bedgraph/unsorted_file"
                        }
                    ],
                    "out": [
                        "#bam-bedgraph-bigwig.cwl/sort_bedgraph/sorted_file"
                    ],
                    "id": "#bam-bedgraph-bigwig.cwl/sort_bedgraph"
                },
                {
                    "run": "#ucsc-bedgraphtobigwig.cwl",
                    "in": [
                        {
                            "source": "#bam-bedgraph-bigwig.cwl/sort_bedgraph/sorted_file",
                            "id": "#bam-bedgraph-bigwig.cwl/sorted_bedgraph_to_bigwig/bedgraph_file"
                        },
                        {
                            "source": "#bam-bedgraph-bigwig.cwl/chrom_length_file",
                            "id": "#bam-bedgraph-bigwig.cwl/sorted_bedgraph_to_bigwig/chrom_length_file"
                        },
                        {
                            "source": "#bam-bedgraph-bigwig.cwl/bigwig_filename",
                            "id": "#bam-bedgraph-bigwig.cwl/sorted_bedgraph_to_bigwig/output_filename"
                        }
                    ],
                    "out": [
                        "#bam-bedgraph-bigwig.cwl/sorted_bedgraph_to_bigwig/bigwig_file"
                    ],
                    "id": "#bam-bedgraph-bigwig.cwl/sorted_bedgraph_to_bigwig"
                }
            ],
            "doc": "Workflow converts input BAM file into bigWig and bedGraph files\n",
            "id": "#bam-bedgraph-bigwig.cwl",
            "http://schema.org/name": "bam-bedgraph-bigwig",
            "http://schema.org/downloadUrl": "https://raw.githubusercontent.com/Barski-lab/workflows/master/workflows/bam-bedgraph-bigwig.cwl",
            "http://schema.org/codeRepository": "https://github.com/Barski-lab/workflows",
            "http://schema.org/license": "http://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/isPartOf": {
                "class": "http://schema.org/CreativeWork",
                "http://schema.org/name": "Common Workflow Language",
                "http://schema.org/url": "http://commonwl.org/"
            },
            "http://schema.org/creator": [
                {
                    "class": "http://schema.org/Organization",
                    "http://schema.org/legalName": "Cincinnati Children's Hospital Medical Center",
                    "http://schema.org/location": [
                        {
                            "class": "http://schema.org/PostalAddress",
                            "http://schema.org/addressCountry": "USA",
                            "http://schema.org/addressLocality": "Cincinnati",
                            "http://schema.org/addressRegion": "OH",
                            "http://schema.org/postalCode": "45229",
                            "http://schema.org/streetAddress": "3333 Burnet Ave",
                            "http://schema.org/telephone": "+1(513)636-4200"
                        }
                    ],
                    "http://schema.org/logo": "https://www.cincinnatichildrens.org/-/media/cincinnati%20childrens/global%20shared/childrens-logo-new.png",
                    "http://schema.org/department": [
                        {
                            "class": "http://schema.org/Organization",
                            "http://schema.org/legalName": "Allergy and Immunology",
                            "http://schema.org/department": [
                                {
                                    "class": "http://schema.org/Organization",
                                    "http://schema.org/legalName": "Barski Research Lab",
                                    "http://schema.org/member": [
                                        {
                                            "class": "http://schema.org/Person",
                                            "http://schema.org/name": "Michael Kotliar",
                                            "http://schema.org/email": "mailto:misha.kotliar@gmail.com",
                                            "http://schema.org/sameAs": [
                                                {
                                                    "id": "#0000-0002-6486-3898"
                                                }
                                            ]
                                        },
                                        {
                                            "class": "http://schema.org/Person",
                                            "http://schema.org/name": "Andrey Kartashov",
                                            "http://schema.org/email": "mailto:Andrey.Kartashov@cchmc.org",
                                            "http://schema.org/sameAs": [
                                                {
                                                    "id": "#0000-0001-9102-5681"
                                                }
                                            ]
                                        }
                                    ]
                                }
                            ]
                        }
                    ]
                }
            ],
            "http://schema.org/about": "Workflow converts input BAM file into bigWig and bedGraph files.\n\nInput BAM file should be sorted by coordinates (required by `bam_to_bedgraph` step).\n\nIf `split` input is not provided use true by default. Default logic is implemented in `valueFrom` field of `split`\ninput inside `bam_to_bedgraph` step to avoid possible bug in cwltool with setting default values for workflow inputs.\n\n`scale` has higher priority over the `mapped_reads_number`. The last one is used to calculate `-scale` parameter for\n`bedtools genomecov` (step `bam_to_bedgraph`) only in a case when input `scale` is not provided. All logic is\nimplemented inside `bedtools-genomecov.cwl`.\n\n`bigwig_filename` defines the output name only for generated bigWig file. `bedgraph_filename` defines the output name\nfor generated bedGraph file and can influence on generated bigWig filename in case when `bigwig_filename` is not provided.\n\nAll workflow inputs and outputs don't have `format` field to avoid format incompatibility errors when workflow is used\nas subworkflow."
        },
        {
            "class": "CommandLineTool",
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement",
                    "expressionLib": [
                        "var default_output_filename = function() { let ext = (inputs.depth == \"-bg\" || inputs.depth == \"-bga\")?\".bedGraph\":\".tab\"; return inputs.input_file.location.split('/').slice(-1)[0].split('.').slice(0,-1).join('.') + ext; };"
                    ]
                }
            ],
            "hints": [
                {
                    "class": "DockerRequirement",
                    "dockerPull": "biowardrobe2/bedtools2:v2.26.0"
                }
            ],
            "inputs": [
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "inputBinding": {
                        "position": 17,
                        "prefix": "-g"
                    },
                    "doc": "Input genome file. Needed only when -i flag. The genome file is tab delimited <chromName><TAB><chromSize>\n",
                    "id": "#bedtools-genomecov.cwl/chrom_length_file"
                },
                {
                    "type": [
                        "null",
                        {
                            "type": "enum",
                            "name": "#bedtools-genomecov.cwl/depth/depth",
                            "symbols": [
                                "#bedtools-genomecov.cwl/depth/depth/-bg",
                                "#bedtools-genomecov.cwl/depth/depth/-bga",
                                "#bedtools-genomecov.cwl/depth/depth/-d",
                                "#bedtools-genomecov.cwl/depth/depth/-dz"
                            ]
                        }
                    ],
                    "inputBinding": {
                        "position": 5
                    },
                    "doc": "Report the depth type. By default, bedtools genomecov will compute a histogram of coverage\nfor the genome file provided (intputs.chrom_length_file)\n",
                    "id": "#bedtools-genomecov.cwl/depth"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 11,
                        "prefix": "-du"
                    },
                    "doc": "Change strand af the mate read (so both reads from the same strand) useful for strand specific.\nWorks for BAM files only\n",
                    "id": "#bedtools-genomecov.cwl/du"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 12,
                        "prefix": "-fs"
                    },
                    "doc": "Set fixed fragment size\n",
                    "id": "#bedtools-genomecov.cwl/fragment_size"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 16,
                        "valueFrom": "${\n  var prefix = ((/.*\\.bam$/i).test(inputs.input_file.path))?'-ibam':'-i';\n  return [prefix, inputs.input_file.path];\n}\n"
                    },
                    "doc": "The input file can be in BAM format (Note: BAM must be sorted by position) or <bed/gff/vcf>.\nPrefix is selected on the base of input file extension\n",
                    "id": "#bedtools-genomecov.cwl/input_file"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 15,
                        "prefix": "-3"
                    },
                    "doc": "Calculate coverage of 3\" positions (instead of entire interval)\n",
                    "id": "#bedtools-genomecov.cwl/m3"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 14,
                        "prefix": "-5"
                    },
                    "doc": "Calculate coverage of 5\" positions (instead of entire interval)\n",
                    "id": "#bedtools-genomecov.cwl/m5"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 7,
                        "prefix": "-scale",
                        "valueFrom": "${\n  if (inputs.scale){\n    return null;\n  } else if (inputs.mapped_reads_number) {\n    return 1000000/inputs.mapped_reads_number;\n  } else {\n    return null;\n  }\n}\n"
                    },
                    "doc": "Optional parameter to calculate scale as 1000000/mapped_reads_number if inputs.scale is not provided\n",
                    "id": "#bedtools-genomecov.cwl/mapped_reads_number"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 13,
                        "prefix": "-max"
                    },
                    "doc": "Combine all positions with a depth >= max into\na single bin in the histogram. Irrelevant\nfor -d and -bedGraph\n- (INTEGER)\n",
                    "id": "#bedtools-genomecov.cwl/max"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "doc": "Name for generated output file\n",
                    "id": "#bedtools-genomecov.cwl/output_filename"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 10,
                        "prefix": "-pc"
                    },
                    "doc": "pair-end chip seq experiment\n",
                    "id": "#bedtools-genomecov.cwl/pairchip"
                },
                {
                    "type": [
                        "null",
                        "float"
                    ],
                    "inputBinding": {
                        "position": 6,
                        "prefix": "-scale"
                    },
                    "doc": "Scale the coverage by a constant factor.\nEach coverage value is multiplied by this factor before being reported.\nUseful for normalizing coverage by, e.g., reads per million (RPM).\n- Default is 1.0; i.e., unscaled.\n- (FLOAT)\n",
                    "id": "#bedtools-genomecov.cwl/scale"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 8,
                        "prefix": "-split"
                    },
                    "doc": "treat \"split\" BAM or BED12 entries as distinct BED intervals.\nwhen computing coverage.\nFor BAM files, this uses the CIGAR \"N\" and \"D\" operations\nto infer the blocks for computing coverage.\nFor BED12 files, this uses the BlockCount, BlockStarts, and BlockEnds\nfields (i.e., columns 10,11,12).\n",
                    "id": "#bedtools-genomecov.cwl/split"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "inputBinding": {
                        "position": 9,
                        "prefix": "-strand"
                    },
                    "doc": "Calculate coverage of intervals from a specific strand.\nWith BED files, requires at least 6 columns (strand is column 6).\n- (STRING): can be + or -\n",
                    "id": "#bedtools-genomecov.cwl/strand"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "${\n  if (inputs.output_filename == null){\n    return default_output_filename();\n  } else {\n    return inputs.output_filename;\n  }\n}\n"
                    },
                    "doc": "Generated genome coverage output file\n",
                    "id": "#bedtools-genomecov.cwl/genome_coverage_file"
                }
            ],
            "stdout": "${\n  if (inputs.output_filename == null){\n    return default_output_filename();\n  } else {\n    return inputs.output_filename;\n  }\n}\n",
            "baseCommand": [
                "bedtools",
                "genomecov"
            ],
            "doc": "Tool calculates genome coverage from input bam/bed/gff/vcf using `bedtools genomecov`\n\nDepending on `input_file` extension additional prefix is used: if `*.bam` use `-ibam`, else use `-i`.\n\n`scale` and `mapped_reads_number` inputs result in the same parameter `-scale`. If `scale` is not provided, check if\n`mapped_reads_number` is not null and calculate `-scale` as `1000000/mapped_reads_number`. If both inputs are\nnull, `bedtools genomecov` will use its default scaling value.\n\n`default_output_filename` function returns default output filename and is used when `output_filename` is not provided.\nDefault output file extention is `.tab`. If bedGraph should be generated (check flags `inputs.depth`), extension is\nupdated to `.bedGraph`. Default basename of the output file is generated on the base of `input_file` basename.\n",
            "id": "#bedtools-genomecov.cwl",
            "http://schema.org/mainEntity": {
                "class": "http://schema.org/SoftwareSourceCode",
                "id": "#bedtools-metadata.yaml",
                "http://schema.org/name": "bowtie2",
                "http://schema.org/about": "A software suite for the comparison, manipulation and annotation of genomic features in browser extensible data (BED) and general feature format (GFF) format. BEDTools also supports the comparison of sequence alignments in BAM format to both BED and GFF features. The tools are extremely efficient and allow the user to compare large datasets (e.g. next-generation sequencing data) with both public and custom genome annotation tracks. BEDTools can be combined with one another as well as with standard UNIX commands, thus facilitating routine genomics tasks as well as pipelines that can quickly answer intricate questions of large genomic datasets.\n",
                "http://schema.org/url": "http://bedtools.readthedocs.org",
                "http://schema.org/codeRepository": "https://github.com/arq5x/bedtools2",
                "http://schema.org/license": [
                    "https://opensource.org/licenses/GPL-2.0"
                ],
                "http://schema.org/targetProduct": {
                    "class": "http://schema.org/SoftwareApplication",
                    "http://schema.org/softwareVersion": "2.26.0",
                    "http://schema.org/applicationCategory": "command line tool"
                },
                "http://schema.org/programmingLanguage": "C++",
                "http://schema.org/publication": [
                    {
                        "class": "http://schema.org/ScholarlyArticle",
                        "id": "#bedtools-metadata.yaml/10.1093/bioinformatics/btq033",
                        "datePublished": "28 January 2010",
                        "http://schema.org/name": "BEDTools: a flexible suite of utilities for comparing genomic features",
                        "http://schema.org/author": [
                            {
                                "class": "http://schema.org/Person",
                                "http://schema.org/name": "Aaron R. Quinlan"
                            },
                            {
                                "class": "http://schema.org/Person",
                                "http://schema.org/name": "Ira M. Hall"
                            }
                        ],
                        "http://schema.org/url": "https://academic.oup.com/bioinformatics/article-lookup/doi/10.1093/bioinformatics/btq033"
                    }
                ],
                "http://schema.org/discussionUrl": [
                    "https://github.com/arq5x/bedtools2/issues",
                    "https://groups.google.com/forum/#!forum/bedtools-discuss"
                ],
                "http://schema.org/creator": [
                    {
                        "class": "http://schema.org/Organization",
                        "http://schema.org/name": "University of Utah",
                        "http://schema.org/member": [
                            {
                                "class": "http://schema.org/Person",
                                "http://schema.org/name": "Aaron Quinlan",
                                "http://schema.org/description": "Main author"
                            },
                            {
                                "class": "http://schema.org/Person",
                                "http://schema.org/name": "Neil Kindlon",
                                "http://schema.org/description": "Main author"
                            }
                        ]
                    }
                ]
            },
            "http://schema.org/name": "bedtools-genomecov",
            "http://schema.org/downloadUrl": "https://raw.githubusercontent.com/Barski-lab/workflows/master/tools/bedtools-genomecov.cwl",
            "http://schema.org/codeRepository": "https://github.com/Barski-lab/workflows",
            "http://schema.org/license": "http://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/isPartOf": {
                "class": "http://schema.org/CreativeWork",
                "http://schema.org/name": "Common Workflow Language",
                "http://schema.org/url": "http://commonwl.org/"
            },
            "http://schema.org/creator": [
                {
                    "class": "http://schema.org/Organization",
                    "http://schema.org/legalName": "Cincinnati Children's Hospital Medical Center",
                    "http://schema.org/location": [
                        {
                            "class": "http://schema.org/PostalAddress",
                            "http://schema.org/addressCountry": "USA",
                            "http://schema.org/addressLocality": "Cincinnati",
                            "http://schema.org/addressRegion": "OH",
                            "http://schema.org/postalCode": "45229",
                            "http://schema.org/streetAddress": "3333 Burnet Ave",
                            "http://schema.org/telephone": "+1(513)636-4200"
                        }
                    ],
                    "http://schema.org/logo": "https://www.cincinnatichildrens.org/-/media/cincinnati%20childrens/global%20shared/childrens-logo-new.png",
                    "http://schema.org/department": [
                        {
                            "class": "http://schema.org/Organization",
                            "http://schema.org/legalName": "Allergy and Immunology",
                            "http://schema.org/department": [
                                {
                                    "class": "http://schema.org/Organization",
                                    "http://schema.org/legalName": "Barski Research Lab",
                                    "http://schema.org/member": [
                                        {
                                            "class": "http://schema.org/Person",
                                            "http://schema.org/name": "Michael Kotliar",
                                            "http://schema.org/email": "mailto:misha.kotliar@gmail.com",
                                            "http://schema.org/sameAs": [
                                                {
                                                    "$import": "#0000-0002-6486-3898"
                                                }
                                            ]
                                        }
                                    ]
                                }
                            ]
                        }
                    ]
                }
            ],
            "http://schema.org/about": "Usage: bedtools genomecov [OPTIONS] -i <bed/gff/vcf> -g <genome>\n\nOptions:\n\t-ibam\t\tThe input file is in BAM format.\n\t\t\tNote: BAM _must_ be sorted by position\n\n\t-d\t\tReport the depth at each genome position (with one-based coordinates).\n\t\t\tDefault behavior is to report a histogram.\n\n\t-dz\t\tReport the depth at each genome position (with zero-based coordinates).\n\t\t\tReports only non-zero positions.\n\t\t\tDefault behavior is to report a histogram.\n\n\t-bg\t\tReport depth in BedGraph format. For details, see:\n\t\t\tgenome.ucsc.edu/goldenPath/help/bedgraph.html\n\n\t-bga\t\tReport depth in BedGraph format, as above (-bg).\n\t\t\tHowever with this option, regions with zero\n\t\t\tcoverage are also reported. This allows one to\n\t\t\tquickly extract all regions of a genome with 0\n\t\t\tcoverage by applying: \"grep -w 0$\" to the output.\n\n\t-split\t\tTreat \"split\" BAM or BED12 entries as distinct BED intervals.\n\t\t\twhen computing coverage.\n\t\t\tFor BAM files, this uses the CIGAR \"N\" and \"D\" operations\n\t\t\tto infer the blocks for computing coverage.\n\t\t\tFor BED12 files, this uses the BlockCount, BlockStarts, and BlockEnds\n\t\t\tfields (i.e., columns 10,11,12).\n\n\t-strand\t\tCalculate coverage of intervals from a specific strand.\n\t\t\tWith BED files, requires at least 6 columns (strand is column 6).\n\t\t\t- (STRING): can be + or -\n\n\t-pc\t\tCalculate coverage of pair-end fragments.\n\t\t\tWorks for BAM files only\n\t-fs\t\tForce to use provided fragment size instead of read length\n\t\t\tWorks for BAM files only\n\t-du\t\tChange strand af the mate read (so both reads from the same strand) useful for strand specific\n\t\t\tWorks for BAM files only\n\t-5\t\tCalculate coverage of 5\" positions (instead of entire interval).\n\n\t-3\t\tCalculate coverage of 3\" positions (instead of entire interval).\n\n\t-max\t\tCombine all positions with a depth >= max into\n\t\t\ta single bin in the histogram. Irrelevant\n\t\t\tfor -d and -bedGraph\n\t\t\t- (INTEGER)\n\n\t-scale\t\tScale the coverage by a constant factor.\n\t\t\tEach coverage value is multiplied by this factor before being reported.\n\t\t\tUseful for normalizing coverage by, e.g., reads per million (RPM).\n\t\t\t- Default is 1.0; i.e., unscaled.\n\t\t\t- (FLOAT)\n\n\t-trackline\tAdds a UCSC/Genome-Browser track line definition in the first line of the output.\n\t\t\t- See here for more details about track line definition:\n\t\t\t      http://genome.ucsc.edu/goldenPath/help/bedgraph.html\n\t\t\t- NOTE: When adding a trackline definition, the output BedGraph can be easily\n\t\t\t      uploaded to the Genome Browser as a custom track,\n\t\t\t      BUT CAN NOT be converted into a BigWig file (w/o removing the first line).\n\n\t-trackopts\tWrites additional track line definition parameters in the first line.\n\t\t\t- Example:\n\t\t\t   -trackopts 'name=\"My Track\" visibility=2 color=255,30,30'\n\t\t\t   Note the use of single-quotes if you have spaces in your parameters.\n\t\t\t- (TEXT)\n\nNotes:\n\t(1) The genome file should tab delimited and structured as follows:\n\t <chromName><TAB><chromSize>\n\n\tFor example, Human (hg19):\n\tchr1\t249250621\n\tchr2\t243199373\n\t...\n\tchr18_gl000207_random\t4262\n\n\t(2) The input BED (-i) file must be grouped by chromosome.\n\t A simple \"sort -k 1,1 <BED> > <BED>.sorted\" will suffice.\n\n\t(3) The input BAM (-ibam) file must be sorted by position.\n\t A \"samtools sort <BAM>\" should suffice.\n\nTips:\n\tOne can use the UCSC Genome Browser's MySQL database to extract\n\tchromosome sizes. For example, H. sapiens:\n\n\tmysql --user=genome --host=genome-mysql.cse.ucsc.edu -A -e \\\n\t\"select chrom, size from hg19.chromInfo\" > hg19.genome\n"
        },
        {
            "class": "CommandLineTool",
            "requirements": [
                {
                    "class": "ShellCommandRequirement"
                },
                {
                    "class": "InlineJavascriptRequirement",
                    "expressionLib": [
                        "var default_output_filename = function(ext) { if (inputs.output_filename != \"\" && !ext){ return inputs.output_filename; } ext = ext || \".sam\"; let root = \"\"; if (inputs.output_filename != \"\"){ root = inputs.output_filename.split('.').slice(0,-1).join('.'); return (root == \"\")?inputs.output_filename+ext:root+ext; } else if (Array.isArray(inputs.upstream_filelist) && inputs.upstream_filelist.length > 0){ root = inputs.upstream_filelist[0].basename.split('.').slice(0,-1).join('.'); return (root == \"\")?inputs.upstream_filelist[0].basename+ext:root+ext; } else if (inputs.upstream_filelist != null){ root = inputs.upstream_filelist.basename.split('.').slice(0,-1).join('.'); return (root == \"\")?inputs.upstream_filelist.basename+ext:root+ext; } else if (Array.isArray(inputs.downstream_filelist) && inputs.downstream_filelist.length > 0){ root = inputs.downstream_filelist[0].basename.split('.').slice(0,-1).join('.'); return (root == \"\")?inputs.downstream_filelist[0].basename+ext:root+ext; } else if (inputs.downstream_filelist != null){ root = inputs.downstream_filelist.basename.split('.').slice(0,-1).join('.'); return (root == \"\")?inputs.downstream_filelist.basename+ext:root+ext; } else if (Array.isArray(inputs.crossbow_filelist) && inputs.crossbow_filelist.length > 0){ root = inputs.crossbow_filelist[0].basename.split('.').slice(0,-1).join('.'); return (root == \"\")?inputs.crossbow_filelist[0].basename+ext:root+ext; } else if (inputs.crossbow_filelist != null){ root = inputs.crossbow_filelist.basename.split('.').slice(0,-1).join('.'); return (root == \"\")?inputs.crossbow_filelist.basename+ext:root+ext; } else { return null; } };"
                    ]
                }
            ],
            "hints": [
                {
                    "class": "DockerRequirement",
                    "dockerPull": "biowardrobe2/bowtie:v1.2.0"
                }
            ],
            "inputs": [
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-B"
                    },
                    "doc": "--offbase <int> leftmost ref offset = <int> in bowtie output (default: 0)\n",
                    "id": "#bowtie-alignreads.cwl/B"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-C"
                    },
                    "doc": "reads and index are in colorspace\n",
                    "id": "#bowtie-alignreads.cwl/C"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-I"
                    },
                    "doc": "--minins <int>  minimum insert size for paired-end alignment (default: 0)\n",
                    "id": "#bowtie-alignreads.cwl/I"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-M"
                    },
                    "doc": "<int> like -m, but reports 1 random hit (MAPQ=0)\n",
                    "id": "#bowtie-alignreads.cwl/M"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-Q"
                    },
                    "doc": "QV file(s) corresponding to CSFASTA inputs; use with -f -C\n",
                    "id": "#bowtie-alignreads.cwl/Q"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--Q1"
                    },
                    "doc": "--Q1/--Q2 <file>   same as -Q, but for mate files 1 and 2 respectively\n",
                    "id": "#bowtie-alignreads.cwl/Q1"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--Q2"
                    },
                    "doc": "--Q1/--Q2 <file>   same as -Q, but for mate files 1 and 2 respectively\n",
                    "id": "#bowtie-alignreads.cwl/Q2"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-X"
                    },
                    "doc": "--maxins <int>  maximum insert size for paired-end alignment (default: 250)\n",
                    "id": "#bowtie-alignreads.cwl/X"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-a"
                    },
                    "doc": "--all           report all alignments per read (much slower than low -k)\n",
                    "id": "#bowtie-alignreads.cwl/a"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--al"
                    },
                    "doc": "<fname>       write aligned reads/pairs to file(s) <fname>\n",
                    "id": "#bowtie-alignreads.cwl/al"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--best"
                    },
                    "doc": "hits guaranteed best stratum; ties broken by quality\n",
                    "id": "#bowtie-alignreads.cwl/best"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-c"
                    },
                    "doc": "query sequences given on cmd line (as <mates>, <singles>)\n",
                    "id": "#bowtie-alignreads.cwl/c"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--chunkmbs"
                    },
                    "doc": "<int>   max megabytes of RAM for best-first search frames (def: 64)\n",
                    "id": "#bowtie-alignreads.cwl/chunkmbs"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-3"
                    },
                    "doc": "--trim3 <int>   trim <int> bases from 3' (right) end of reads\n",
                    "id": "#bowtie-alignreads.cwl/clip_3p_end"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-5"
                    },
                    "doc": "--trim5 <int>   trim <int> bases from 5' (left) end of reads\n",
                    "id": "#bowtie-alignreads.cwl/clip_5p_end"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--col-cqual"
                    },
                    "doc": "print original colorspace quals, not decoded quals\n",
                    "id": "#bowtie-alignreads.cwl/col_cqual"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--col-cseq"
                    },
                    "doc": "print aligned colorspace seqs as colors, not decoded bases\n",
                    "id": "#bowtie-alignreads.cwl/col_cseq"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--col-keepends"
                    },
                    "doc": "keep nucleotides at extreme ends of decoded alignment\n",
                    "id": "#bowtie-alignreads.cwl/col_keepends"
                },
                {
                    "type": [
                        "null",
                        "File",
                        {
                            "type": "array",
                            "items": "File"
                        }
                    ],
                    "inputBinding": {
                        "itemSeparator": ",",
                        "position": 86,
                        "prefix": "-12"
                    },
                    "doc": "Comma-separated list of files containing Crossbow-style reads.\nCan be a mixture of paired and unpaired.  Specify \"-\"for stdin.\n",
                    "id": "#bowtie-alignreads.cwl/crossbow_filelist"
                },
                {
                    "type": [
                        "null",
                        "File",
                        {
                            "type": "array",
                            "items": "File"
                        }
                    ],
                    "inputBinding": {
                        "itemSeparator": ",",
                        "position": 85
                    },
                    "doc": "Comma-separated list of files containing downstream mates (or the\nsequences themselves if -c is set) paired with mates in <m1>\n",
                    "id": "#bowtie-alignreads.cwl/downstream_filelist"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-e"
                    },
                    "doc": "--maqerr <int>  max sum of mismatch quals across alignment for -n (def: 70)\n",
                    "id": "#bowtie-alignreads.cwl/e"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-f"
                    },
                    "doc": "query input files are (multi-)FASTA .fa/.mfa\n",
                    "id": "#bowtie-alignreads.cwl/f"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--ff"
                    },
                    "doc": "--fr/--rf/--ff     -1, -2 mates align fw/rev, rev/fw, fw/fw (default: --fr)\n",
                    "id": "#bowtie-alignreads.cwl/ff"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--fr"
                    },
                    "doc": "--fr/--rf/--ff     -1, -2 mates align fw/rev, rev/fw, fw/fw (default: --fr)\n",
                    "id": "#bowtie-alignreads.cwl/fr"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--fullref"
                    },
                    "doc": "write entire ref name (default: only up to 1st space)\n",
                    "id": "#bowtie-alignreads.cwl/fullref"
                },
                {
                    "type": "Directory",
                    "inputBinding": {
                        "position": 81,
                        "valueFrom": "${\n    for (var i = 0; i < self.listing.length; i++) {\n        if (self.listing[i].path.split('.').slice(-3).join('.') == 'rev.1.ebwt' ||\n            self.listing[i].path.split('.').slice(-3).join('.') == 'rev.1.ebwtl'){\n          return self.listing[i].path.split('.').slice(0,-3).join('.');\n        }\n    }\n    return null;\n}\n"
                    },
                    "doc": "Folder with Bowtie indices\n",
                    "id": "#bowtie-alignreads.cwl/indices_folder"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--integer-quals"
                    },
                    "doc": "qualities are given as space-separated integers (not ASCII)\n",
                    "id": "#bowtie-alignreads.cwl/integer_quals"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-k"
                    },
                    "doc": "<int>           report up to <int> good alignments per read (default: 1)\n",
                    "id": "#bowtie-alignreads.cwl/k"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-l"
                    },
                    "doc": "--seedlen <int> seed length for -n (default: 28)\n",
                    "id": "#bowtie-alignreads.cwl/l"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--large-index"
                    },
                    "doc": "force usage of a 'large' index, even if a small one is present\n",
                    "id": "#bowtie-alignreads.cwl/large_index"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-m"
                    },
                    "doc": "<int>           suppress all alignments if > <int> exist (def: no limit)\n",
                    "id": "#bowtie-alignreads.cwl/m"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--mapq"
                    },
                    "doc": "<int>       default mapping quality (MAPQ) to print for SAM alignments\n",
                    "id": "#bowtie-alignreads.cwl/mapq"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--max"
                    },
                    "doc": "<fname>      write reads/pairs over -m limit to file(s) <fname>\n",
                    "id": "#bowtie-alignreads.cwl/max"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--maxbts"
                    },
                    "doc": "<int>     max # backtracks for -n 2/3 (default: 125, 800 for --best)\n",
                    "id": "#bowtie-alignreads.cwl/maxbts"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--mm"
                    },
                    "doc": "use memory-mapped I/O for index; many 'bowtie's can share\n",
                    "id": "#bowtie-alignreads.cwl/mm"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-n"
                    },
                    "doc": "--seedmms <int> max mismatches in seed (can be 0-3, default: -n 2)\n",
                    "id": "#bowtie-alignreads.cwl/n"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--nofw"
                    },
                    "doc": "--norc      do not align to forward/reverse-complement reference strand\n",
                    "id": "#bowtie-alignreads.cwl/nofw"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--nomaqround"
                    },
                    "doc": "disable Maq-like quality rounding for -n (nearest 10 <= 30)\n",
                    "id": "#bowtie-alignreads.cwl/nomaqround"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-o"
                    },
                    "doc": "--offrate <int> override offrate of index; must be >= index's offrate\n",
                    "id": "#bowtie-alignreads.cwl/o"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "inputBinding": {
                        "position": 90,
                        "valueFrom": "$(default_output_filename())"
                    },
                    "default": "",
                    "doc": "Generates default output filename on the base of upstream_filelist/downstream_filelist files\n",
                    "id": "#bowtie-alignreads.cwl/output_filename"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--pairtries"
                    },
                    "doc": "<int>  max # attempts to find mate for anchor hit (default: 100)\n",
                    "id": "#bowtie-alignreads.cwl/pairtries"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--phred33-quals"
                    },
                    "doc": "input quals are Phred+33 (default)\n",
                    "id": "#bowtie-alignreads.cwl/phred33_quals"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--phred64-quals"
                    },
                    "doc": "input quals are Phred+64 (same as --solexa1.3-quals)\n",
                    "id": "#bowtie-alignreads.cwl/phred64_quals"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-q"
                    },
                    "doc": "query input files are FASTQ .fq/.fastq (default)\n",
                    "id": "#bowtie-alignreads.cwl/q"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--quiet"
                    },
                    "doc": "print nothing but the alignments\n",
                    "id": "#bowtie-alignreads.cwl/quiet"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-r"
                    },
                    "doc": "query input files are raw one-sequence-per-line\n",
                    "id": "#bowtie-alignreads.cwl/r"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--reads-per-batch"
                    },
                    "doc": "# of reads to read from input file at once (default: 16)\n",
                    "id": "#bowtie-alignreads.cwl/reads_per_batch"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--refidx"
                    },
                    "doc": "refer to ref. seqs by 0-based index rather than name\n",
                    "id": "#bowtie-alignreads.cwl/refidx"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--refout"
                    },
                    "doc": "write alignments to files refXXXXX.map, 1 map per reference\n",
                    "id": "#bowtie-alignreads.cwl/refout"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--rf"
                    },
                    "doc": "--fr/--rf/--ff     -1, -2 mates align fw/rev, rev/fw, fw/fw (default: --fr)\n",
                    "id": "#bowtie-alignreads.cwl/rf"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-s"
                    },
                    "doc": "--skip <int>    skip the first <int> reads/pairs in the input\n",
                    "id": "#bowtie-alignreads.cwl/s"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-S"
                    },
                    "doc": "--sam write hits in SAM format\n",
                    "id": "#bowtie-alignreads.cwl/sam"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--sam-RG"
                    },
                    "doc": "<text>    add <text> (usually \"lab=value\") to @RG line of SAM header\n",
                    "id": "#bowtie-alignreads.cwl/sam_RG"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--sam-nohead"
                    },
                    "doc": "supppress header lines (starting with @) for SAM output\n",
                    "id": "#bowtie-alignreads.cwl/sam_nohead"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--sam-nosq"
                    },
                    "doc": "supppress @SQ header lines for SAM output\n",
                    "id": "#bowtie-alignreads.cwl/sam_nosq"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--seed"
                    },
                    "doc": "<int>       seed for random number generator\n",
                    "id": "#bowtie-alignreads.cwl/seed"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--shmem"
                    },
                    "doc": "use shared mem for index\n",
                    "id": "#bowtie-alignreads.cwl/shmem"
                },
                {
                    "type": [
                        "null",
                        "float"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--snpfrac"
                    },
                    "doc": "<dec>    approx. fraction of SNP bases (e.g. 0.001); sets --snpphred\n",
                    "id": "#bowtie-alignreads.cwl/snpfrac"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--snpphred"
                    },
                    "doc": "<int>   Phred penalty for SNP when decoding colorspace (def: 30)\n",
                    "id": "#bowtie-alignreads.cwl/snpphred"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--solexa1.3-quals"
                    },
                    "doc": "input quals are from GA Pipeline ver. >= 1.3\n",
                    "id": "#bowtie-alignreads.cwl/solexa1.3_quals"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--solexa-quals"
                    },
                    "doc": "input quals are from GA Pipeline ver. < 1.3\n",
                    "id": "#bowtie-alignreads.cwl/solexa_quals"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--strata"
                    },
                    "doc": "hits in sub-optimal strata aren't reported (requires --best)\n",
                    "id": "#bowtie-alignreads.cwl/strata"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--suppress"
                    },
                    "doc": "<cols>  suppresses given columns (comma-delim'ed) in default output\n",
                    "id": "#bowtie-alignreads.cwl/suppress"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-t"
                    },
                    "doc": "--time          print wall-clock time taken by search phases\n",
                    "id": "#bowtie-alignreads.cwl/t"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-p"
                    },
                    "doc": "--threads <int> number of alignment threads to launch (default: 1)\n",
                    "id": "#bowtie-alignreads.cwl/threads"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-u"
                    },
                    "doc": "--qupto <int>   stop after first <int> reads/pairs (excl. skipped reads)\n",
                    "id": "#bowtie-alignreads.cwl/u"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--un"
                    },
                    "doc": "<fname>       write unaligned reads/pairs to file(s) <fname>\n",
                    "id": "#bowtie-alignreads.cwl/un"
                },
                {
                    "type": [
                        "null",
                        "File",
                        {
                            "type": "array",
                            "items": "File"
                        }
                    ],
                    "inputBinding": {
                        "itemSeparator": ",",
                        "position": 83
                    },
                    "doc": "Comma-separated list of files containing upstream mates (or the\nsequences themselves, if -c is set) paired with mates in <m2>\n",
                    "id": "#bowtie-alignreads.cwl/upstream_filelist"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-v"
                    },
                    "doc": "report end-to-end hits w/ <=v mismatches; ignore qualities\n",
                    "id": "#bowtie-alignreads.cwl/v"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--verbose"
                    },
                    "doc": "verbose output (for debugging)\n",
                    "id": "#bowtie-alignreads.cwl/verbose"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-y"
                    },
                    "doc": "--tryhard try hard to find valid alignments, at the expense of speed\n",
                    "id": "#bowtie-alignreads.cwl/y"
                }
            ],
            "outputs": [
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputBinding": {
                        "glob": "$(inputs.al)"
                    },
                    "id": "#bowtie-alignreads.cwl/aligned_file"
                },
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(default_output_filename(\".bw\"))"
                    },
                    "id": "#bowtie-alignreads.cwl/log_file"
                },
                {
                    "type": "int",
                    "outputBinding": {
                        "loadContents": true,
                        "glob": "$(default_output_filename(\".bw\"))",
                        "outputEval": "${\n  let mappedRegex = /alignment\\:.*/;\n  return parseInt(self[0].contents.match(mappedRegex)[0].split(\" \")[1]);\n}\n"
                    },
                    "id": "#bowtie-alignreads.cwl/mapped_reads_number"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputBinding": {
                        "glob": "$(inputs.max)"
                    },
                    "id": "#bowtie-alignreads.cwl/multimapped_file"
                },
                {
                    "type": [
                        "null",
                        {
                            "type": "array",
                            "items": "File"
                        }
                    ],
                    "outputBinding": {
                        "glob": "*ref*.map*"
                    },
                    "id": "#bowtie-alignreads.cwl/refout_file"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputBinding": {
                        "glob": "$(default_output_filename())"
                    },
                    "id": "#bowtie-alignreads.cwl/sam_file"
                },
                {
                    "type": "int",
                    "outputBinding": {
                        "loadContents": true,
                        "glob": "$(default_output_filename(\".bw\"))",
                        "outputEval": "${\n  let totalRegex = /processed\\:.*/;\n  return parseInt(self[0].contents.match(totalRegex)[0].split(\" \")[1]);\n}\n"
                    },
                    "id": "#bowtie-alignreads.cwl/total_reads_number"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputBinding": {
                        "glob": "$(inputs.un)"
                    },
                    "id": "#bowtie-alignreads.cwl/unaligned_file"
                },
                {
                    "type": "int",
                    "outputBinding": {
                        "loadContents": true,
                        "glob": "$(default_output_filename(\".bw\"))",
                        "outputEval": "${\n  let unmappedRegex = /align\\:.*/;\n  return parseInt(self[0].contents.match(unmappedRegex)[0].split(\" \")[1]);\n}\n"
                    },
                    "id": "#bowtie-alignreads.cwl/unmapped_reads_number"
                }
            ],
            "baseCommand": [
                "bowtie"
            ],
            "arguments": [
                {
                    "valueFrom": "${\n  if (inputs.upstream_filelist && inputs.downstream_filelist){\n    return \"-1\";\n  }\n  return null;\n}\n",
                    "position": 82
                },
                {
                    "valueFrom": "${\n  if (inputs.upstream_filelist && inputs.downstream_filelist){\n    return \"-2\";\n  }\n  return null;\n}\n",
                    "position": 84
                },
                {
                    "valueFrom": "${\n  return ' 2> ' + default_output_filename(\".bw\");\n}\n",
                    "position": 100000,
                    "shellQuote": false
                }
            ],
            "doc": "Tool maps input raw reads files to reference genome using Bowtie.\n\n`default_output_filename` function returns default name for SAM output and log files. In case when `sam` and\n`output_filename` inputs are not set, default filename will have `.sam` extension but format may not correspond SAM\nspecification. To set output filename manually use `output_filename` input. Default output filename is based on\n`output_filename` or basename of `upstream_filelist`, `downstream_filelist` or `crossbow_filelist` file (if array,\nthe first file in array is taken). If function is called without argenments and `output_filename` input is set, it\nwill be returned from the function.\n\nFor single-end input data any of the `upstream_filelist` or `downstream_filelist` inputs can be used.\n\nLog filename (`log_file` output) is generated by `default_output_filename` function with ex='.bw'\n\n`indices_folder` defines folder to contain Bowtie indices. Based on the first found file with `rev.1.ebwt` or\n`rev.1.ebwtl` extension, bowtie index prefix is returned from input's `valueFrom` field.\n",
            "id": "#bowtie-alignreads.cwl",
            "http://schema.org/mainEntity": {
                "class": "http://schema.org/SoftwareSourceCode",
                "id": "#bowtie-metadata.yaml",
                "http://schema.org/name": "bowtie2",
                "http://schema.org/about": "Bowtie is an ultrafast, memory-efficient short read aligner. It aligns short DNA sequences (reads)\nto the human genome at a rate of over 25 million 35-bp reads per hour. Bowtie indexes the genome\nwith a Burrows-Wheeler index to keep its memory footprint small: typically about 2.2 GB for\nthe human genome (2.9 GB for paired-end).\n",
                "http://schema.org/url": "http://bowtie-bio.sourceforge.net/index.shtml",
                "http://schema.org/codeRepository": "https://github.com/BenLangmead/bowtie",
                "http://schema.org/license": [
                    "https://opensource.org/licenses/GPL-3.0"
                ],
                "http://schema.org/targetProduct": {
                    "class": "http://schema.org/SoftwareApplication",
                    "http://schema.org/softwareVersion": "1.2.0",
                    "http://schema.org/applicationCategory": "command line tool"
                },
                "http://schema.org/programmingLanguage": "C++",
                "http://schema.org/publication": [
                    {
                        "class": "http://schema.org/ScholarlyArticle",
                        "id": "#bowtie-metadata.yaml/10.1186/gb-2009-10-3-r25",
                        "datePublished": "04 March 2009",
                        "http://schema.org/name": "Ultrafast and memory-efficient alignment of short DNA sequences to the human genome",
                        "http://schema.org/author": [
                            {
                                "class": "http://schema.org/Person",
                                "http://schema.org/name": "Ben Langmead"
                            },
                            {
                                "class": "http://schema.org/Person",
                                "http://schema.org/name": "Steven L Salzberg"
                            },
                            {
                                "class": "http://schema.org/Person",
                                "http://schema.org/name": "Cole Trapnell"
                            },
                            {
                                "class": "http://schema.org/Person",
                                "http://schema.org/name": "Mihai Pop"
                            }
                        ],
                        "http://schema.org/url": "https://genomebiology.biomedcentral.com/articles/10.1186/gb-2009-10-3-r25"
                    }
                ],
                "http://schema.org/discussionUrl": [
                    "https://github.com/BenLangmead/bowtie/issues"
                ],
                "http://schema.org/creator": [
                    {
                        "class": "http://schema.org/Organization",
                        "http://schema.org/name": "Johns Hopkins University",
                        "http://schema.org/member": [
                            {
                                "class": "http://schema.org/Person",
                                "http://schema.org/name": "Ben Langmead",
                                "http://schema.org/description": "Main author"
                            }
                        ]
                    }
                ]
            },
            "http://schema.org/name": "bowtie",
            "http://schema.org/downloadUrl": "https://raw.githubusercontent.com/Barski-lab/workflows/master/tools/bowtie.cwl",
            "http://schema.org/codeRepository": "https://github.com/Barski-lab/workflows",
            "http://schema.org/license": "http://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/isPartOf": {
                "class": "http://schema.org/CreativeWork",
                "http://schema.org/name": "Common Workflow Language",
                "http://schema.org/url": "http://commonwl.org/"
            },
            "http://schema.org/creator": [
                {
                    "class": "http://schema.org/Organization",
                    "http://schema.org/legalName": "Cincinnati Children's Hospital Medical Center",
                    "http://schema.org/location": [
                        {
                            "class": "http://schema.org/PostalAddress",
                            "http://schema.org/addressCountry": "USA",
                            "http://schema.org/addressLocality": "Cincinnati",
                            "http://schema.org/addressRegion": "OH",
                            "http://schema.org/postalCode": "45229",
                            "http://schema.org/streetAddress": "3333 Burnet Ave",
                            "http://schema.org/telephone": "+1(513)636-4200"
                        }
                    ],
                    "http://schema.org/logo": "https://www.cincinnatichildrens.org/-/media/cincinnati%20childrens/global%20shared/childrens-logo-new.png",
                    "http://schema.org/department": [
                        {
                            "class": "http://schema.org/Organization",
                            "http://schema.org/legalName": "Allergy and Immunology",
                            "http://schema.org/department": [
                                {
                                    "class": "http://schema.org/Organization",
                                    "http://schema.org/legalName": "Barski Research Lab",
                                    "http://schema.org/member": [
                                        {
                                            "class": "http://schema.org/Person",
                                            "http://schema.org/name": "Andrey Kartashov",
                                            "http://schema.org/email": "mailto:Andrey.Kartashov@cchmc.org",
                                            "http://schema.org/sameAs": [
                                                {
                                                    "$import": "#0000-0001-9102-5681"
                                                }
                                            ]
                                        },
                                        {
                                            "class": "http://schema.org/Person",
                                            "http://schema.org/name": "Michael Kotliar",
                                            "http://schema.org/email": "mailto:misha.kotliar@gmail.com",
                                            "http://schema.org/sameAs": [
                                                {
                                                    "$import": "#0000-0002-6486-3898"
                                                }
                                            ]
                                        }
                                    ]
                                }
                            ]
                        }
                    ]
                }
            ],
            "http://schema.org/about": "Usage:\nbowtie [options]* <ebwt> {-1 <m1> -2 <m2> | --12 <r> | <s>} [<hit>]\n\n  <m1>    Comma-separated list of files containing upstream mates (or the\n          sequences themselves, if -c is set) paired with mates in <m2>\n  <m2>    Comma-separated list of files containing downstream mates (or the\n          sequences themselves if -c is set) paired with mates in <m1>\n  <r>     Comma-separated list of files containing Crossbow-style reads.  Can be\n          a mixture of paired and unpaired.  Specify \"-\" for stdin.\n  <s>     Comma-separated list of files containing unpaired reads, or the\n          sequences themselves, if -c is set.  Specify \"-\" for stdin.\n  <hit>   File to write hits to (default: stdout)\nInput:\n  -q                 query input files are FASTQ .fq/.fastq (default)\n  -f                 query input files are (multi-)FASTA .fa/.mfa\n  -r                 query input files are raw one-sequence-per-line\n  -c                 query sequences given on cmd line (as <mates>, <singles>)\n  -C                 reads and index are in colorspace\n  -Q/--quals <file>  QV file(s) corresponding to CSFASTA inputs; use with -f -C\n  --Q1/--Q2 <file>   same as -Q, but for mate files 1 and 2 respectively\n  -s/--skip <int>    skip the first <int> reads/pairs in the input\n  -u/--qupto <int>   stop after first <int> reads/pairs (excl. skipped reads)\n  -5/--trim5 <int>   trim <int> bases from 5' (left) end of reads\n  -3/--trim3 <int>   trim <int> bases from 3' (right) end of reads\n  --phred33-quals    input quals are Phred+33 (default)\n  --phred64-quals    input quals are Phred+64 (same as --solexa1.3-quals)\n  --solexa-quals     input quals are from GA Pipeline ver. < 1.3\n  --solexa1.3-quals  input quals are from GA Pipeline ver. >= 1.3\n  --integer-quals    qualities are given as space-separated integers (not ASCII)\n  --large-index      force usage of a 'large' index, even if a small one is present\nAlignment:\n  -v <int>           report end-to-end hits w/ <=v mismatches; ignore qualities\n    or\n  -n/--seedmms <int> max mismatches in seed (can be 0-3, default: -n 2)\n  -e/--maqerr <int>  max sum of mismatch quals across alignment for -n (def: 70)\n  -l/--seedlen <int> seed length for -n (default: 28)\n  --nomaqround       disable Maq-like quality rounding for -n (nearest 10 <= 30)\n  -I/--minins <int>  minimum insert size for paired-end alignment (default: 0)\n  -X/--maxins <int>  maximum insert size for paired-end alignment (default: 250)\n  --fr/--rf/--ff     -1, -2 mates align fw/rev, rev/fw, fw/fw (default: --fr)\n  --nofw/--norc      do not align to forward/reverse-complement reference strand\n  --maxbts <int>     max # backtracks for -n 2/3 (default: 125, 800 for --best)\n  --pairtries <int>  max # attempts to find mate for anchor hit (default: 100)\n  -y/--tryhard       try hard to find valid alignments, at the expense of speed\n  --chunkmbs <int>   max megabytes of RAM for best-first search frames (def: 64)\n --reads-per-batch   # of reads to read from input file at once (default: 16)\nReporting:\n  -k <int>           report up to <int> good alignments per read (default: 1)\n  -a/--all           report all alignments per read (much slower than low -k)\n  -m <int>           suppress all alignments if > <int> exist (def: no limit)\n  -M <int>           like -m, but reports 1 random hit (MAPQ=0); requires --best\n  --best             hits guaranteed best stratum; ties broken by quality\n  --strata           hits in sub-optimal strata aren't reported (requires --best)\nOutput:\n  -t/--time          print wall-clock time taken by search phases\n  -B/--offbase <int> leftmost ref offset = <int> in bowtie output (default: 0)\n  --quiet            print nothing but the alignments\n  --refout           write alignments to files refXXXXX.map, 1 map per reference\n  --refidx           refer to ref. seqs by 0-based index rather than name\n  --al <fname>       write aligned reads/pairs to file(s) <fname>\n  --un <fname>       write unaligned reads/pairs to file(s) <fname>\n  --max <fname>      write reads/pairs over -m limit to file(s) <fname>\n  --suppress <cols>  suppresses given columns (comma-delim'ed) in default output\n  --fullref          write entire ref name (default: only up to 1st space)\nColorspace:\n  --snpphred <int>   Phred penalty for SNP when decoding colorspace (def: 30)\n     or\n  --snpfrac <dec>    approx. fraction of SNP bases (e.g. 0.001); sets --snpphred\n  --col-cseq         print aligned colorspace seqs as colors, not decoded bases\n  --col-cqual        print original colorspace quals, not decoded quals\n  --col-keepends     keep nucleotides at extreme ends of decoded alignment\nSAM:\n  -S/--sam           write hits in SAM format\n  --mapq <int>       default mapping quality (MAPQ) to print for SAM alignments\n  --sam-nohead       supppress header lines (starting with @) for SAM output\n  --sam-nosq         supppress @SQ header lines for SAM output\n  --sam-RG <text>    add <text> (usually \"lab=value\") to @RG line of SAM header\nPerformance:\n  -o/--offrate <int> override offrate of index; must be >= index's offrate\n  -p/--threads <int> number of alignment threads to launch (default: 1)\n  --mm               use memory-mapped I/O for index; many 'bowtie's can share\n  --shmem            use shared mem for index; many 'bowtie's can share\nOther:\n  --seed <int>       seed for random number generator\n  --verbose          verbose output (for debugging)\n  --version          print version information and quit\n  -h/--help          print this usage message\n"
        },
        {
            "class": "CommandLineTool",
            "hints": [
                {
                    "class": "DockerRequirement",
                    "dockerPull": "biowardrobe2/scidap:v0.0.3"
                }
            ],
            "inputs": [
                {
                    "type": [
                        "File",
                        {
                            "type": "array",
                            "items": "File"
                        }
                    ],
                    "inputBinding": {
                        "position": 2
                    },
                    "id": "#custom-bash.cwl/input_file"
                },
                {
                    "type": [
                        "null",
                        "string",
                        {
                            "type": "array",
                            "items": "string"
                        }
                    ],
                    "inputBinding": {
                        "position": 3
                    },
                    "id": "#custom-bash.cwl/param"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "default": "cat \"$0\" | grep \"$1\" | sed \"s/$1//g\"  > `basename $0`\n",
                    "inputBinding": {
                        "position": 1
                    },
                    "id": "#custom-bash.cwl/script"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "*"
                    },
                    "id": "#custom-bash.cwl/output_file"
                }
            ],
            "baseCommand": [
                "bash",
                "-c"
            ],
            "doc": "Tool to run custom script set as `script` input with arguments from `param`.\nDefault script runs sed command over the input file and exports results to the file with the same name as input's basename\n",
            "id": "#custom-bash.cwl",
            "http://schema.org/name": "custom-bash",
            "http://schema.org/downloadUrl": "https://raw.githubusercontent.com/Barski-lab/workflows/master/tools/custom-bash.cwl",
            "http://schema.org/codeRepository": "https://github.com/Barski-lab/workflows",
            "http://schema.org/license": "http://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/isPartOf": {
                "class": "http://schema.org/CreativeWork",
                "http://schema.org/name": "Common Workflow Language",
                "http://schema.org/url": "http://commonwl.org/"
            },
            "http://schema.org/creator": [
                {
                    "class": "http://schema.org/Organization",
                    "http://schema.org/legalName": "Cincinnati Children's Hospital Medical Center",
                    "http://schema.org/location": [
                        {
                            "class": "http://schema.org/PostalAddress",
                            "http://schema.org/addressCountry": "USA",
                            "http://schema.org/addressLocality": "Cincinnati",
                            "http://schema.org/addressRegion": "OH",
                            "http://schema.org/postalCode": "45229",
                            "http://schema.org/streetAddress": "3333 Burnet Ave",
                            "http://schema.org/telephone": "+1(513)636-4200"
                        }
                    ],
                    "http://schema.org/logo": "https://www.cincinnatichildrens.org/-/media/cincinnati%20childrens/global%20shared/childrens-logo-new.png",
                    "http://schema.org/department": [
                        {
                            "class": "http://schema.org/Organization",
                            "http://schema.org/legalName": "Allergy and Immunology",
                            "http://schema.org/department": [
                                {
                                    "class": "http://schema.org/Organization",
                                    "http://schema.org/legalName": "Barski Research Lab",
                                    "http://schema.org/member": [
                                        {
                                            "class": "http://schema.org/Person",
                                            "http://schema.org/name": "Michael Kotliar",
                                            "http://schema.org/email": "mailto:michael.kotliar@cchmc.org",
                                            "http://schema.org/sameAs": [
                                                {
                                                    "$import": "#0000-0002-6486-3898"
                                                }
                                            ]
                                        }
                                    ]
                                }
                            ]
                        }
                    ]
                }
            ],
            "http://schema.org/about": "Custom bash script runner"
        },
        {
            "class": "CommandLineTool",
            "requirements": [
                {
                    "class": "ShellCommandRequirement"
                }
            ],
            "hints": [
                {
                    "class": "DockerRequirement",
                    "dockerPull": "biowardrobe2/scidap:v0.0.3"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 6
                    },
                    "doc": "Compressed or uncompressed FASTQ file\n",
                    "id": "#extract-fastq.cwl/compressed_file"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "inputBinding": {
                        "position": 7
                    },
                    "default": ".fastq",
                    "doc": "Default extension for the extracted file\n",
                    "id": "#extract-fastq.cwl/output_file_ext"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "default": "#!/bin/bash\nshopt -s nocaseglob\n\nFILE=$0\nDEFAULT_EXT=$1\n\nEXT_LIST=( \".fastq\" \".fq\" )\n\nBASENAME=$(basename \"$FILE\")\nROOT_NAME=\"${BASENAME%.*}\"\n\nfor ITEM in $EXT_LIST; do\n  if [[ $ROOT_NAME == *$ITEM ]]; then\n    DEFAULT_EXT=\"\"\n  fi\ndone\n\nT=`file -b \"${FILE}\" | awk '{print $1}'`\ncase \"${T}\" in\n  \"bzip2\"|\"gzip\"|\"Zip\")\n    7z e -so \"${FILE}\" > \"${ROOT_NAME}${DEFAULT_EXT}\"\n    ;;\n  \"ASCII\")\n    cp \"${FILE}\" \"${ROOT_NAME}${DEFAULT_EXT}\" || true\n    ;;\n  *)\n    echo \"Error: file type unknown\"\n    exit 1\nesac\n",
                    "inputBinding": {
                        "position": 5
                    },
                    "doc": "Bash script to extract compressed FASTQ file\n",
                    "id": "#extract-fastq.cwl/script"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "*"
                    },
                    "id": "#extract-fastq.cwl/fastq_file"
                }
            ],
            "baseCommand": [
                "bash",
                "-c"
            ],
            "doc": "Tool to decompress input FASTQ file\nBash script's logic:\n- disable case sensitive glob check\n- check if root name of input file already include '.fastq' or '.fq' extension. If yes, set DEFAULT_EXT to \"\"\n- check file type, decompress if needed\n- return 1, if file type is not recognized\nThis script also works of input file doesn't have any extension at all\n",
            "id": "#extract-fastq.cwl",
            "http://schema.org/name": "extract-fastq",
            "http://schema.org/downloadUrl": "https://raw.githubusercontent.com/Barski-lab/workflows/master/tools/extract-fastq.cwl",
            "http://schema.org/codeRepository": "https://github.com/Barski-lab/workflows",
            "http://schema.org/license": "http://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/isPartOf": {
                "class": "http://schema.org/CreativeWork",
                "http://schema.org/name": "Common Workflow Language",
                "http://schema.org/url": "http://commonwl.org/"
            },
            "http://schema.org/creator": [
                {
                    "class": "http://schema.org/Organization",
                    "http://schema.org/legalName": "Cincinnati Children's Hospital Medical Center",
                    "http://schema.org/location": [
                        {
                            "class": "http://schema.org/PostalAddress",
                            "http://schema.org/addressCountry": "USA",
                            "http://schema.org/addressLocality": "Cincinnati",
                            "http://schema.org/addressRegion": "OH",
                            "http://schema.org/postalCode": "45229",
                            "http://schema.org/streetAddress": "3333 Burnet Ave",
                            "http://schema.org/telephone": "+1(513)636-4200"
                        }
                    ],
                    "http://schema.org/logo": "https://www.cincinnatichildrens.org/-/media/cincinnati%20childrens/global%20shared/childrens-logo-new.png",
                    "http://schema.org/department": [
                        {
                            "class": "http://schema.org/Organization",
                            "http://schema.org/legalName": "Allergy and Immunology",
                            "http://schema.org/department": [
                                {
                                    "class": "http://schema.org/Organization",
                                    "http://schema.org/legalName": "Barski Research Lab",
                                    "http://schema.org/member": [
                                        {
                                            "class": "http://schema.org/Person",
                                            "http://schema.org/name": "Michael Kotliar",
                                            "http://schema.org/email": "mailto:misha.kotliar@gmail.com",
                                            "http://schema.org/sameAs": [
                                                {
                                                    "$import": "#0000-0002-6486-3898"
                                                }
                                            ]
                                        }
                                    ]
                                }
                            ]
                        }
                    ]
                }
            ],
            "http://schema.org/about": "Tool to decompress input FASTQ file"
        },
        {
            "class": "CommandLineTool",
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                }
            ],
            "hints": [
                {
                    "class": "DockerRequirement",
                    "dockerPull": "biowardrobe2/fastqc:v0.11.5"
                }
            ],
            "inputs": [
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "inputBinding": {
                        "position": 9,
                        "prefix": "--adapters"
                    },
                    "doc": "Specifies a non-default file which contains the list of\nadapter sequences which will be explicity searched against\nthe library. The file must contain sets of named adapters\nin the form name[tab]sequence.  Lines prefixed with a hash\nwill be ignored.\n",
                    "id": "#fastqc.cwl/adapters"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 13,
                        "prefix": "--casava"
                    },
                    "doc": "Files come from raw casava output. Files in the same sample\ngroup (differing only by the group number) will be analysed\nas a set rather than individually. Sequences with the filter\nflag set in the header will be excluded from the analysis.\nFiles must have the same names given to them by casava\n(including being gzipped and ending with .gz) otherwise they\nwon't be grouped together correctly.\n",
                    "id": "#fastqc.cwl/casava"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "inputBinding": {
                        "position": 8,
                        "prefix": "--contaminants"
                    },
                    "doc": "Specifies a non-default file which contains the list of\ncontaminants to screen overrepresented sequences against.\nThe file must contain sets of named contaminants in the\nform name[tab]sequence.  Lines prefixed with a hash will\nbe ignored.\n",
                    "id": "#fastqc.cwl/contaminants"
                },
                {
                    "type": [
                        "File"
                    ],
                    "inputBinding": {
                        "position": 50
                    },
                    "doc": "Input bam,sam,bam_mapped,sam_mapped or fastq file\n",
                    "id": "#fastqc.cwl/fastq_file"
                },
                {
                    "type": [
                        "null",
                        {
                            "type": "enum",
                            "name": "#fastqc.cwl/format_enum/format",
                            "symbols": [
                                "#fastqc.cwl/format_enum/format/bam",
                                "#fastqc.cwl/format_enum/format/sam",
                                "#fastqc.cwl/format_enum/format/bam_mapped",
                                "#fastqc.cwl/format_enum/format/sam_mapped",
                                "#fastqc.cwl/format_enum/format/fastq"
                            ]
                        }
                    ],
                    "inputBinding": {
                        "position": 6,
                        "prefix": "--format"
                    },
                    "doc": "Bypasses the normal sequence file format detection and\nforces the program to use the specified format.  Valid\nformats are bam,sam,bam_mapped,sam_mapped and fastq\n",
                    "id": "#fastqc.cwl/format_enum"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 15,
                        "prefix": "--nogroup"
                    },
                    "doc": "Disable grouping of bases for reads >50bp. All reports will\nshow data for every base in the read.  WARNING: Using this\noption will cause fastqc to crash and burn if you use it on\nreally long reads, and your plots may end up a ridiculous size.\nYou have been warned!\n",
                    "id": "#fastqc.cwl/hide_group"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 11,
                        "prefix": "--kmers"
                    },
                    "doc": "Specifies the length of Kmer to look for in the Kmer content\nmodule. Specified Kmer length must be between 2 and 10. Default\nlength is 7 if not specified.\n",
                    "id": "#fastqc.cwl/kmers"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "inputBinding": {
                        "position": 10,
                        "prefix": "--limits"
                    },
                    "doc": "Specifies a non-default file which contains a set of criteria\nwhich will be used to determine the warn/error limits for the\nvarious modules.  This file can also be used to selectively\nremove some modules from the output all together.  The format\nneeds to mirror the default limits.txt file found in the\nConfiguration folder.\n",
                    "id": "#fastqc.cwl/limits"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 14,
                        "prefix": "--nofilter"
                    },
                    "doc": "If running with --casava then don't remove read flagged by\ncasava as poor quality when performing the QC analysis.\n",
                    "id": "#fastqc.cwl/nofilter"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 7,
                        "prefix": "--threads"
                    },
                    "doc": "Specifies the number of files which can be processed\nsimultaneously.  Each thread will be allocated 250MB of\nmemory so you shouldn't run more threads than your\navailable memory will cope with, and not more than\n6 threads on a 32 bit machine\n",
                    "id": "#fastqc.cwl/threads"
                }
            ],
            "outputs": [
                {
                    "type": [
                        "File"
                    ],
                    "outputBinding": {
                        "glob": "${\n  return \"*/summary.txt\";\n}\n"
                    },
                    "id": "#fastqc.cwl/summary_file"
                },
                {
                    "type": [
                        "File"
                    ],
                    "outputBinding": {
                        "glob": "*.zip"
                    },
                    "id": "#fastqc.cwl/zipped_file"
                }
            ],
            "baseCommand": [
                "fastqc",
                "--extract",
                "--outdir",
                "."
            ],
            "doc": "Tool runs FastQC from Babraham Bioinformatics\n",
            "id": "#fastqc.cwl",
            "http://schema.org/mainEntity": {
                "class": "http://schema.org/SoftwareSourceCode",
                "id": "#fastqc-metadata.yaml",
                "http://schema.org/name": "fastqc",
                "http://schema.org/about": "FastQC is a program designed to spot potential problems in high througput sequencing datasets.\nIt runs a set of analyses on one or more raw sequence files in fastq or bam format and produces\na report which summarises the results.\n",
                "http://schema.org/url": "http://www.bioinformatics.babraham.ac.uk/projects/fastqc/",
                "http://schema.org/codeRepository": "https://github.com/s-andrews/FastQC/releases",
                "http://schema.org/license": [
                    "https://opensource.org/licenses/GPL-2.0"
                ],
                "http://schema.org/targetProduct": {
                    "class": "http://schema.org/SoftwareApplication",
                    "http://schema.org/softwareVersion": "0.11.5",
                    "http://schema.org/applicationCategory": "command line tool"
                },
                "http://schema.org/programmingLanguage": "Java",
                "http://schema.org/discussionUrl": [
                    "https://github.com/s-andrews/FastQC/issues"
                ],
                "http://schema.org/creator": [
                    {
                        "class": "http://schema.org/Organization",
                        "http://schema.org/name": "Babraham Bioinformatics",
                        "http://schema.org/member": [
                            {
                                "class": "http://schema.org/Person",
                                "http://schema.org/name": "Simon Andrews"
                            }
                        ]
                    }
                ]
            },
            "http://schema.org/name": "fastqc",
            "http://schema.org/downloadUrl": "https://raw.githubusercontent.com/Barski-lab/workflows/master/tools/fastqc.cwl",
            "http://schema.org/codeRepository": "https://github.com/Barski-lab/workflows",
            "http://schema.org/license": "http://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/isPartOf": {
                "class": "http://schema.org/CreativeWork",
                "http://schema.org/name": "Common Workflow Language",
                "http://schema.org/url": "http://commonwl.org/"
            },
            "http://schema.org/creator": [
                {
                    "class": "http://schema.org/Organization",
                    "http://schema.org/legalName": "Cincinnati Children's Hospital Medical Center",
                    "http://schema.org/location": [
                        {
                            "class": "http://schema.org/PostalAddress",
                            "http://schema.org/addressCountry": "USA",
                            "http://schema.org/addressLocality": "Cincinnati",
                            "http://schema.org/addressRegion": "OH",
                            "http://schema.org/postalCode": "45229",
                            "http://schema.org/streetAddress": "3333 Burnet Ave",
                            "http://schema.org/telephone": "+1(513)636-4200"
                        }
                    ],
                    "http://schema.org/logo": "https://www.cincinnatichildrens.org/-/media/cincinnati%20childrens/global%20shared/childrens-logo-new.png",
                    "http://schema.org/department": [
                        {
                            "class": "http://schema.org/Organization",
                            "http://schema.org/legalName": "Allergy and Immunology",
                            "http://schema.org/department": [
                                {
                                    "class": "http://schema.org/Organization",
                                    "http://schema.org/legalName": "Barski Research Lab",
                                    "http://schema.org/member": [
                                        {
                                            "class": "http://schema.org/Person",
                                            "http://schema.org/name": "Michael Kotliar",
                                            "http://schema.org/email": "mailto:misha.kotliar@gmail.com",
                                            "http://schema.org/sameAs": [
                                                {
                                                    "$import": "#0000-0002-6486-3898"
                                                }
                                            ]
                                        }
                                    ]
                                }
                            ]
                        }
                    ]
                }
            ],
            "http://schema.org/about": "SYNOPSIS\n\n    fastqc seqfile1 seqfile2 .. seqfileN\n\n    fastqc [-o output dir] [--(no)extract] [-f fastq|bam|sam]\n           [-c contaminant file] seqfile1 .. seqfileN\n\nDESCRIPTION\n\n    FastQC reads a set of sequence files and produces from each one a quality\n    control report consisting of a number of different modules, each one of\n    which will help to identify a different potential type of problem in your\n    data.\n\n    If no files to process are specified on the command line then the program\n    will start as an interactive graphical application.  If files are provided\n    on the command line then the program will run with no user interaction\n    required.  In this mode it is suitable for inclusion into a standardised\n    analysis pipeline.\n\n    The options for the program as as follows:\n\n    -h --help       Print this help file and exit\n\n    -v --version    Print the version of the program and exit\n\n    -o --outdir     Create all output files in the specified output directory.\n                    Please note that this directory must exist as the program\n                    will not create it.  If this option is not set then the\n                    output file for each sequence file is created in the same\n                    directory as the sequence file which was processed.\n\n    --casava        Files come from raw casava output. Files in the same sample\n                    group (differing only by the group number) will be analysed\n                    as a set rather than individually. Sequences with the filter\n                    flag set in the header will be excluded from the analysis.\n                    Files must have the same names given to them by casava\n                    (including being gzipped and ending with .gz) otherwise they\n                    won't be grouped together correctly.\n\n    --nano          Files come from naopore sequences and are in fast5 format. In\n                    this mode you can pass in directories to process and the program\n                    will take in all fast5 files within those directories and produce\n                    a single output file from the sequences found in all files.\n\n    --nofilter      If running with --casava then don't remove read flagged by\n                    casava as poor quality when performing the QC analysis.\n\n    --extract       If set then the zipped output file will be uncompressed in\n                    the same directory after it has been created.  By default\n                    this option will be set if fastqc is run in non-interactive\n                    mode.\n\n    -j --java       Provides the full path to the java binary you want to use to\n                    launch fastqc. If not supplied then java is assumed to be in\n                    your path.\n\n    --noextract     Do not uncompress the output file after creating it.  You\n                    should set this option if you do not wish to uncompress\n                    the output when running in non-interactive mode.\n\n    --nogroup       Disable grouping of bases for reads >50bp. All reports will\n                    show data for every base in the read.  WARNING: Using this\n                    option will cause fastqc to crash and burn if you use it on\n                    really long reads, and your plots may end up a ridiculous size.\n                    You have been warned!\n\n    -f --format     Bypasses the normal sequence file format detection and\n                    forces the program to use the specified format.  Valid\n                    formats are bam,sam,bam_mapped,sam_mapped and fastq\n\n    -t --threads    Specifies the number of files which can be processed\n                    simultaneously.  Each thread will be allocated 250MB of\n                    memory so you shouldn't run more threads than your\n                    available memory will cope with, and not more than\n                    6 threads on a 32 bit machine\n\n    -c              Specifies a non-default file which contains the list of\n    --contaminants  contaminants to screen overrepresented sequences against.\n                    The file must contain sets of named contaminants in the\n                    form name[tab]sequence.  Lines prefixed with a hash will\n                    be ignored.\n\n    -a              Specifies a non-default file which contains the list of\n    --adapters      adapter sequences which will be explicity searched against\n                    the library. The file must contain sets of named adapters\n                    in the form name[tab]sequence.  Lines prefixed with a hash\n                    will be ignored.\n\n    -l              Specifies a non-default file which contains a set of criteria\n    --limits        which will be used to determine the warn/error limits for the\n                    various modules.  This file can also be used to selectively\n                    remove some modules from the output all together.  The format\n                    needs to mirror the default limits.txt file found in the\n                    Configuration folder.\n\n   -k --kmers       Specifies the length of Kmer to look for in the Kmer content\n                    module. Specified Kmer length must be between 2 and 10. Default\n                    length is 7 if not specified.\n\n   -q --quiet       Supress all progress messages on stdout and only report errors.\n\n   -d --dir         Selects a directory to be used for temporary files written when\n                    generating report images. Defaults to system temp directory if\n                    not specified.\n"
        },
        {
            "class": "CommandLineTool",
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement",
                    "expressionLib": [
                        "var default_output_filename = function() { return inputs.input_file.location.split('/').slice(-1)[0].split('.').slice(0,-1).join('.') + \".fastxstat\" };"
                    ]
                }
            ],
            "hints": [
                {
                    "class": "DockerRequirement",
                    "dockerPull": "biowardrobe2/fastx_toolkit:v0.0.14"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 10,
                        "prefix": "-i"
                    },
                    "doc": "FASTA/Q input file. If FASTA file is given, only nucleotides distribution is calculated (there's no quality info)\n",
                    "id": "#fastx-quality-stats.cwl/input_file"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 5,
                        "prefix": "-N"
                    },
                    "doc": "New output format (with more information per nucleotide/cycle).\ncycle (previously called 'column') = cycle number\nmax-count\nFor each nucleotide in the cycle (ALL/A/C/G/T/N):\n    count   = number of bases found in this column.\n    min     = Lowest quality score value found in this column.\n    max     = Highest quality score value found in this column.\n    sum     = Sum of quality score values for this column.\n    mean    = Mean quality score value for this column.\n    Q1\t= 1st quartile quality score.\n    med\t= Median quality score.\n    Q3\t= 3rd quartile quality score.\n    IQR\t= Inter-Quartile range (Q3-Q1).\n    lW\t= 'Left-Whisker' value (for boxplotting).\n    rW\t= 'Right-Whisker' value (for boxplotting).\n",
                    "id": "#fastx-quality-stats.cwl/new_output_format"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "inputBinding": {
                        "position": 11,
                        "prefix": "-o",
                        "valueFrom": "${\n    if (self == \"\"){\n      return default_output_filename();\n    } else {\n      return self;\n    }\n}\n"
                    },
                    "default": "",
                    "doc": "Output file to store generated statistics. If not provided - return from default_output_filename function\n",
                    "id": "#fastx-quality-stats.cwl/output_filename"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "${\n    if (inputs.output_filename == \"\"){\n      return default_output_filename();\n    } else {\n      return inputs.output_filename;\n    }\n}\n"
                    },
                    "doc": "Generated statistics file",
                    "id": "#fastx-quality-stats.cwl/statistics_file"
                }
            ],
            "baseCommand": [
                "fastx_quality_stats"
            ],
            "doc": "Tool calculates statistics on the base of FASTQ file quality scores.\nIf `output_filename` is not provided call function `default_output_filename` to return default output file name\ngenerated as `input_file` basename + `.fastxstat` extension.\n",
            "id": "#fastx-quality-stats.cwl",
            "http://schema.org/mainEntity": {
                "class": "http://schema.org/SoftwareSourceCode",
                "id": "#fastx-toolkit-metadata.yaml",
                "http://schema.org/name": "fastx-toolkit",
                "http://schema.org/about": "The FASTX-Toolkit is a collection of command line tools for Short-Reads FASTA/FASTQ files preprocessing. Available Tools:\n  FASTQ-to-FASTA converter (Convert FASTQ files to FASTA files)\n  FASTQ Information (Chart Quality Statistics and Nucleotide Distribution)\n  FASTQ/A Collapser (Collapsing identical sequences in a FASTQ/A file into a single sequence)\n  FASTQ/A Trimmer (Shortening reads in a FASTQ or FASTQ files, removing barcodes or noise)\n  FASTQ/A Renamer (Renames the sequence identifiers in FASTQ/A file)\n  FASTQ/A Clipper (Removing sequencing adapters/linkers)\n  FASTQ/A Reverse-Complement (Producing the Reverse-complement of each sequence in a FASTQ/FASTA file)\n  FASTQ/A Barcode splitter (Splitting a FASTQ/FASTA files containning multiple samples)\n  FASTA Formatter (changes the width of sequences line in a FASTA file)\n  FASTA Nucleotide Changer (Convets FASTA sequences from/to RNA/DNA)\n  FASTQ Quality Filter (Filters sequences based on quality)\n  FASTQ Quality Trimmer (Trims (cuts) sequences based on quality)\n  FASTQ Masker (Masks nucleotides with 'N' (or other character) based on quality)\n",
                "http://schema.org/url": "http://hannonlab.cshl.edu/fastx_toolkit/index.html",
                "http://schema.org/codeRepository": "https://github.com/agordon/fastx_toolkit",
                "http://schema.org/license": [
                    "https://opensource.org/licenses/GPL-3.0"
                ],
                "http://schema.org/targetProduct": {
                    "class": "http://schema.org/SoftwareApplication",
                    "http://schema.org/softwareVersion": "0.0.14",
                    "http://schema.org/applicationCategory": "command line tool"
                },
                "http://schema.org/programmingLanguage": "C",
                "http://schema.org/discussionUrl": [
                    "https://github.com/agordon/fastx_toolkit/issues"
                ],
                "http://schema.org/creator": [
                    {
                        "class": "http://schema.org/Organization",
                        "http://schema.org/name": "The Hannon Lab",
                        "http://schema.org/member": [
                            {
                                "class": "http://schema.org/Person",
                                "http://schema.org/name": "Assaf Gordon",
                                "http://schema.org/description": "Main author"
                            }
                        ]
                    }
                ]
            },
            "http://schema.org/name": "fastx-quality-stats",
            "http://schema.org/downloadUrl": "https://raw.githubusercontent.com/Barski-lab/workflows/master/tools/fastx-quality-stats.cwl",
            "http://schema.org/codeRepository": "https://github.com/Barski-lab/workflows",
            "http://schema.org/license": "http://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/isPartOf": {
                "class": "http://schema.org/CreativeWork",
                "http://schema.org/name": "Common Workflow Language",
                "http://schema.org/url": "http://commonwl.org/"
            },
            "http://schema.org/creator": [
                {
                    "class": "http://schema.org/Organization",
                    "http://schema.org/legalName": "Cincinnati Children's Hospital Medical Center",
                    "http://schema.org/location": [
                        {
                            "class": "http://schema.org/PostalAddress",
                            "http://schema.org/addressCountry": "USA",
                            "http://schema.org/addressLocality": "Cincinnati",
                            "http://schema.org/addressRegion": "OH",
                            "http://schema.org/postalCode": "45229",
                            "http://schema.org/streetAddress": "3333 Burnet Ave",
                            "http://schema.org/telephone": "+1(513)636-4200"
                        }
                    ],
                    "http://schema.org/logo": "https://www.cincinnatichildrens.org/-/media/cincinnati%20childrens/global%20shared/childrens-logo-new.png",
                    "http://schema.org/department": [
                        {
                            "class": "http://schema.org/Organization",
                            "http://schema.org/legalName": "Allergy and Immunology",
                            "http://schema.org/department": [
                                {
                                    "class": "http://schema.org/Organization",
                                    "http://schema.org/legalName": "Barski Research Lab",
                                    "http://schema.org/member": [
                                        {
                                            "class": "http://schema.org/Person",
                                            "http://schema.org/name": "Michael Kotliar",
                                            "http://schema.org/email": "mailto:misha.kotliar@gmail.com",
                                            "http://schema.org/sameAs": [
                                                {
                                                    "$import": "#0000-0002-6486-3898"
                                                }
                                            ]
                                        }
                                    ]
                                }
                            ]
                        }
                    ]
                }
            ],
            "http://schema.org/about": "usage: fastx_quality_stats [-h] [-N] [-i INFILE] [-o OUTFILE]\nPart of FASTX Toolkit 0.0.14 by A. Gordon (assafgordon@gmail.com)\n   [-h] = This helpful help screen.\n   [-i INFILE]  = FASTQ input file. default is STDIN.\n   [-o OUTFILE] = TEXT output file. default is STDOUT.\n   [-N]         = New output format (with more information per nucleotide/cycle).\nThe *OLD* output TEXT file will have the following fields (one row per column):\n\tcolumn\t= column number (1 to 36 for a 36-cycles read solexa file)\n\tcount   = number of bases found in this column.\n\tmin     = Lowest quality score value found in this column.\n\tmax     = Highest quality score value found in this column.\n\tsum     = Sum of quality score values for this column.\n\tmean    = Mean quality score value for this column.\n\tQ1\t= 1st quartile quality score.\n\tmed\t= Median quality score.\n\tQ3\t= 3rd quartile quality score.\n\tIQR\t= Inter-Quartile range (Q3-Q1).\n\tlW\t= 'Left-Whisker' value (for boxplotting).\n\trW\t= 'Right-Whisker' value (for boxplotting).\n\tA_Count\t= Count of 'A' nucleotides found in this column.\n\tC_Count\t= Count of 'C' nucleotides found in this column.\n\tG_Count\t= Count of 'G' nucleotides found in this column.\n\tT_Count\t= Count of 'T' nucleotides found in this column.\n\tN_Count = Count of 'N' nucleotides found in this column.\n\tmax-count = max. number of bases (in all cycles)\nThe *NEW* output format:\n\tcycle (previously called 'column') = cycle number\n\tmax-count\n  For each nucleotide in the cycle (ALL/A/C/G/T/N):\n\t\tcount   = number of bases found in this column.\n\t\tmin     = Lowest quality score value found in this column.\n\t\tmax     = Highest quality score value found in this column.\n\t\tsum     = Sum of quality score values for this column.\n\t\tmean    = Mean quality score value for this column.\n\t\tQ1\t= 1st quartile quality score.\n\t\tmed\t= Median quality score.\n\t\tQ3\t= 3rd quartile quality score.\n\t\tIQR\t= Inter-Quartile range (Q3-Q1).\n\t\tlW\t= 'Left-Whisker' value (for boxplotting).\n\t\trW\t= 'Right-Whisker' value (for boxplotting).\n"
        },
        {
            "class": "CommandLineTool",
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement",
                    "expressionLib": [
                        "var default_output_filename = function() { return inputs.unsorted_file.location.split('/').slice(-1)[0]; };"
                    ]
                }
            ],
            "hints": [
                {
                    "class": "DockerRequirement",
                    "dockerPull": "biowardrobe2/scidap:v0.0.2"
                }
            ],
            "inputs": [
                {
                    "type": {
                        "type": "array",
                        "items": "string",
                        "inputBinding": {
                            "prefix": "-k"
                        }
                    },
                    "inputBinding": {
                        "position": 1
                    },
                    "doc": "-k, --key=POS1[,POS2]\nstart a key at POS1, end it at POS2 (origin 1)\n",
                    "id": "#linux-sort.cwl/key"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "doc": "Name for generated output file\n",
                    "id": "#linux-sort.cwl/output_filename"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 4
                    },
                    "id": "#linux-sort.cwl/unsorted_file"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "${\n  if (inputs.output_filename == null){\n    return default_output_filename();\n  } else {\n    return inputs.output_filename;\n  }\n}\n"
                    },
                    "doc": "Sorted file\n",
                    "id": "#linux-sort.cwl/sorted_file"
                }
            ],
            "stdout": "${\n  if (inputs.output_filename == null){\n    return default_output_filename();\n  } else {\n    return inputs.output_filename;\n  }\n}\n",
            "baseCommand": [
                "sort"
            ],
            "doc": "Tool sorts data from `unsorted_file` by key\n\n`default_output_filename` function returns file name identical to `unsorted_file`, if `output_filename` is not provided.\n",
            "id": "#linux-sort.cwl",
            "http://schema.org/name": "linux-sort",
            "http://schema.org/downloadUrl": "https://raw.githubusercontent.com/Barski-lab/workflows/master/tools/linux-sort.cwl",
            "http://schema.org/codeRepository": "https://github.com/Barski-lab/workflows",
            "http://schema.org/license": "http://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/isPartOf": {
                "class": "http://schema.org/CreativeWork",
                "http://schema.org/name": "Common Workflow Language",
                "http://schema.org/url": "http://commonwl.org/"
            },
            "http://schema.org/creator": [
                {
                    "class": "http://schema.org/Organization",
                    "http://schema.org/legalName": "Cincinnati Children's Hospital Medical Center",
                    "http://schema.org/location": [
                        {
                            "class": "http://schema.org/PostalAddress",
                            "http://schema.org/addressCountry": "USA",
                            "http://schema.org/addressLocality": "Cincinnati",
                            "http://schema.org/addressRegion": "OH",
                            "http://schema.org/postalCode": "45229",
                            "http://schema.org/streetAddress": "3333 Burnet Ave",
                            "http://schema.org/telephone": "+1(513)636-4200"
                        }
                    ],
                    "http://schema.org/logo": "https://www.cincinnatichildrens.org/-/media/cincinnati%20childrens/global%20shared/childrens-logo-new.png",
                    "http://schema.org/department": [
                        {
                            "class": "http://schema.org/Organization",
                            "http://schema.org/legalName": "Allergy and Immunology",
                            "http://schema.org/department": [
                                {
                                    "class": "http://schema.org/Organization",
                                    "http://schema.org/legalName": "Barski Research Lab",
                                    "http://schema.org/member": [
                                        {
                                            "class": "http://schema.org/Person",
                                            "http://schema.org/name": "Andrey Kartashov",
                                            "http://schema.org/email": "mailto:Andrey.Kartashov@cchmc.org",
                                            "http://schema.org/sameAs": [
                                                {
                                                    "$import": "#0000-0001-9102-5681"
                                                }
                                            ]
                                        },
                                        {
                                            "class": "http://schema.org/Person",
                                            "http://schema.org/name": "Michael Kotliar",
                                            "http://schema.org/email": "mailto:misha.kotliar@gmail.com",
                                            "http://schema.org/sameAs": [
                                                {
                                                    "$import": "#0000-0002-6486-3898"
                                                }
                                            ]
                                        }
                                    ]
                                }
                            ]
                        }
                    ]
                }
            ]
        },
        {
            "class": "CommandLineTool",
            "requirements": [
                {
                    "class": "ShellCommandRequirement"
                },
                {
                    "class": "InlineJavascriptRequirement",
                    "expressionLib": [
                        "var get_output_filename = function(ext) { ext = ext || \"\"; if (inputs.output_filename == null){ let root = inputs.rsem_isoforms_file.basename.split('.').slice(0,-1).join('.'); return (root == \"\")?inputs.rsem_isoforms_file.basename+ext:root+ext; } else { return inputs.output_filename; } };"
                    ]
                }
            ],
            "hints": [
                {
                    "class": "DockerRequirement",
                    "dockerPull": "biowardrobe2/scidap:v0.0.3"
                }
            ],
            "inputs": [
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "doc": "Name for output file\n",
                    "id": "#python-make-biowardrobe-isoforms.cwl/output_filename"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 7
                    },
                    "doc": "*.ti file from RSEM indices folder to include sorted information about processed isoforms\n",
                    "id": "#python-make-biowardrobe-isoforms.cwl/rsem_annotation_file"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 6
                    },
                    "doc": "Generated by RSEM isoform file\n",
                    "id": "#python-make-biowardrobe-isoforms.cwl/rsem_isoforms_file"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "default": "#!/usr/bin/env python\nimport sys\nopts = {\n    2: lambda l : l.strip(),\n    3: lambda l : l.strip().split()[0],\n    4: lambda l : [str(int(l.strip().split()[1])-1), l.strip().split()[-1]]\n}\nprint \"RefseqId,GeneId,Chrom,TxStart,TxEnd,Strand,TotalReads,Rpkm\"\nwith open(sys.argv[1], 'r') as iso_stream, open(sys.argv[2], 'r') as anno_stream:\n    iso_stream.readline()\n    anno_stream.readline()\n    for iso_line in iso_stream:\n        iso_list = iso_line.strip().split('\\t')\n        result = []\n        for idx in range(6):\n            anno_line = anno_stream.readline().strip()\n            if idx in opts.keys(): result.append(opts[idx](anno_line))\n        print ','.join( [iso_list[0],iso_list[1],result[0],result[2][0],result[2][1],result[1],iso_list[4],iso_list[6]])\n",
                    "inputBinding": {
                        "position": 5
                    },
                    "doc": "Python script to generate BioWardrobe compatible isforoms file from RSEM outputs\n",
                    "id": "#python-make-biowardrobe-isoforms.cwl/script"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "*"
                    },
                    "id": "#python-make-biowardrobe-isoforms.cwl/biowardrobe_isoforms_file"
                }
            ],
            "baseCommand": [
                "python",
                "-c"
            ],
            "arguments": [
                {
                    "valueFrom": "$(\" > \" + get_output_filename(\".csv\"))",
                    "position": 100000,
                    "shellQuote": false
                }
            ],
            "doc": "Tool to generate BioWardrobe compatible isoforms file from RSEM outputs.\n`rsem_annotation_file` and `rsem_isoforms_file` are supposed to have identical order and number of isoforms.\nFPKM value is used intead of RPKM.\n",
            "id": "#python-make-biowardrobe-isoforms.cwl",
            "http://schema.org/name": "python-make-biowardrobe-isoforms",
            "http://schema.org/downloadUrl": "https://raw.githubusercontent.com/Barski-lab/workflows/master/tools/python-make-biowardrobe-isoforms.cwl",
            "http://schema.org/codeRepository": "https://github.com/Barski-lab/workflows",
            "http://schema.org/license": "http://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/isPartOf": {
                "class": "http://schema.org/CreativeWork",
                "http://schema.org/name": "Common Workflow Language",
                "http://schema.org/url": "http://commonwl.org/"
            },
            "http://schema.org/creator": [
                {
                    "class": "http://schema.org/Organization",
                    "http://schema.org/legalName": "Cincinnati Children's Hospital Medical Center",
                    "http://schema.org/location": [
                        {
                            "class": "http://schema.org/PostalAddress",
                            "http://schema.org/addressCountry": "USA",
                            "http://schema.org/addressLocality": "Cincinnati",
                            "http://schema.org/addressRegion": "OH",
                            "http://schema.org/postalCode": "45229",
                            "http://schema.org/streetAddress": "3333 Burnet Ave",
                            "http://schema.org/telephone": "+1(513)636-4200"
                        }
                    ],
                    "http://schema.org/logo": "https://www.cincinnatichildrens.org/-/media/cincinnati%20childrens/global%20shared/childrens-logo-new.png",
                    "http://schema.org/department": [
                        {
                            "class": "http://schema.org/Organization",
                            "http://schema.org/legalName": "Allergy and Immunology",
                            "http://schema.org/department": [
                                {
                                    "class": "http://schema.org/Organization",
                                    "http://schema.org/legalName": "Barski Research Lab",
                                    "http://schema.org/member": [
                                        {
                                            "class": "http://schema.org/Person",
                                            "http://schema.org/name": "Michael Kotliar",
                                            "http://schema.org/email": "mailto:misha.kotliar@gmail.com",
                                            "http://schema.org/sameAs": [
                                                {
                                                    "$import": "#0000-0002-6486-3898"
                                                }
                                            ]
                                        }
                                    ]
                                }
                            ]
                        }
                    ]
                }
            ],
            "http://schema.org/about": "Runs python code from the `script` input\n"
        },
        {
            "class": "CommandLineTool",
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement",
                    "expressionLib": [
                        "var get_target_name = function() { return inputs.target_filename.split('/').slice(-1)[0]; }"
                    ]
                }
            ],
            "hints": [
                {
                    "class": "DockerRequirement",
                    "dockerPull": "biowardrobe2/scidap:v0.0.2"
                }
            ],
            "inputs": [
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "default": "#!/bin/bash\ncp $0 $1\nif [ -f $0.bai ]; then\n  cp $0.bai $1.bai\nfi\n",
                    "inputBinding": {
                        "position": 1
                    },
                    "id": "#rename.cwl/script"
                },
                {
                    "type": [
                        "File"
                    ],
                    "inputBinding": {
                        "position": 5
                    },
                    "id": "#rename.cwl/source_file"
                },
                {
                    "type": "string",
                    "inputBinding": {
                        "position": 6,
                        "valueFrom": "$(get_target_name())"
                    },
                    "id": "#rename.cwl/target_filename"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(get_target_name())"
                    },
                    "secondaryFiles": "${\n    if (inputs.source_file.secondaryFiles && inputs.source_file.secondaryFiles.length > 0){\n      return inputs.target_filename+\".bai\";\n    } else {\n      return \"null\";\n    }\n  }\n",
                    "id": "#rename.cwl/target_file"
                }
            ],
            "baseCommand": [
                "bash",
                "-c"
            ],
            "doc": "Tool renames `source_file` to `target_filename`.\nInput `target_filename` should be set as string. If it's a full path, only basename will be used.\nIf BAI file is present, it will be renamed too\n",
            "id": "#rename.cwl",
            "http://schema.org/name": "rename",
            "http://schema.org/downloadUrl": "https://raw.githubusercontent.com/Barski-lab/workflows/master/tools/rename.cwl",
            "http://schema.org/codeRepository": "https://github.com/Barski-lab/workflows",
            "http://schema.org/license": "http://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/isPartOf": {
                "class": "http://schema.org/CreativeWork",
                "http://schema.org/name": "Common Workflow Language",
                "http://schema.org/url": "http://commonwl.org/"
            },
            "http://schema.org/creator": [
                {
                    "class": "http://schema.org/Organization",
                    "http://schema.org/legalName": "Cincinnati Children's Hospital Medical Center",
                    "http://schema.org/location": [
                        {
                            "class": "http://schema.org/PostalAddress",
                            "http://schema.org/addressCountry": "USA",
                            "http://schema.org/addressLocality": "Cincinnati",
                            "http://schema.org/addressRegion": "OH",
                            "http://schema.org/postalCode": "45229",
                            "http://schema.org/streetAddress": "3333 Burnet Ave",
                            "http://schema.org/telephone": "+1(513)636-4200"
                        }
                    ],
                    "http://schema.org/logo": "https://www.cincinnatichildrens.org/-/media/cincinnati%20childrens/global%20shared/childrens-logo-new.png",
                    "http://schema.org/department": [
                        {
                            "class": "http://schema.org/Organization",
                            "http://schema.org/legalName": "Allergy and Immunology",
                            "http://schema.org/department": [
                                {
                                    "class": "http://schema.org/Organization",
                                    "http://schema.org/legalName": "Barski Research Lab",
                                    "http://schema.org/member": [
                                        {
                                            "class": "http://schema.org/Person",
                                            "http://schema.org/name": "Michael Kotliar",
                                            "http://schema.org/email": "mailto:misha.kotliar@gmail.com",
                                            "http://schema.org/sameAs": [
                                                {
                                                    "$import": "#0000-0002-6486-3898"
                                                }
                                            ]
                                        }
                                    ]
                                }
                            ]
                        }
                    ]
                }
            ],
            "http://schema.org/about": "cp source target"
        },
        {
            "class": "CommandLineTool",
            "requirements": [
                {
                    "class": "ShellCommandRequirement"
                },
                {
                    "class": "InlineJavascriptRequirement",
                    "expressionLib": [
                        "var default_output_filename = function() { if (Array.isArray(inputs.upstream_read_file) && inputs.upstream_read_file.length | 0){ return inputs.upstream_read_file[0].basename.split('.').slice(0,-1).join('.'); } else if (inputs.upstream_read_file != null){ return inputs.upstream_read_file.basename.split('.').slice(0,-1).join('.'); } else if (Array.isArray(inputs.downstream_read_file) && inputs.downstream_read_file.length | 0){ return inputs.downstream_read_file[0].basename.split('.').slice(0,-1).join('.'); } else if (inputs.downstream_read_file != null){ return inputs.downstream_read_file.basename.split('.').slice(0,-1).join('.'); } else if (inputs.input_aligned != null){ return inputs.input_aligned.basename.split('.').slice(0,-1).join('.'); } else { return null; } };"
                    ]
                }
            ],
            "hints": [
                {
                    "class": "DockerRequirement",
                    "dockerPull": "biowardrobe2/rsem:v1.3.0"
                }
            ],
            "inputs": [
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 91,
                        "prefix": "--append-names"
                    },
                    "doc": "If gene_name/transcript_name is available, append it to the end of gene_id/transcript_id (separated by '_')\nin files 'sample_name.isoforms.results' and 'sample_name.genes.results'.\n(Default: off)\n",
                    "id": "#rsem-calculate-expression.cwl/append_names"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 93,
                        "prefix": "--bowtie2"
                    },
                    "doc": "Use Bowtie 2 instead of Bowtie to align reads. Since currently RSEM does not handle indel,\nlocal and discordant alignments, the Bowtie2 parameters are set in a way to avoid those alignments.\nIn particular, we use options '--sensitive --dpad 0 --gbar 99999999 --mp 1,1 --np 1 --score-min L,0,-0.1' by default.\nThe last parameter of '--score-min', '-0.1', is the negative of maximum mismatch rate.\nThis rate can be set by option '--bowtie2-mismatch-rate'. If reads are paired-end, we additionally use options\n'--no-mixed' and '--no-discordant'.\n(Default: off)\n",
                    "id": "#rsem-calculate-expression.cwl/bowtie2"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 68,
                        "prefix": "--bowtie2-k"
                    },
                    "doc": "(Bowtie 2 parameter) Find up to <int| alignments per read.\n(Default: 200)\n",
                    "id": "#rsem-calculate-expression.cwl/bowtie2_k"
                },
                {
                    "type": [
                        "null",
                        "double"
                    ],
                    "inputBinding": {
                        "position": 69,
                        "prefix": "--bowtie2-mismatch-rate"
                    },
                    "doc": "(Bowtie 2 parameter) The maximum mismatch rate allowed.\n(Default: 0.1)\n",
                    "id": "#rsem-calculate-expression.cwl/bowtie2_mismatch_rate"
                },
                {
                    "type": [
                        "null",
                        {
                            "type": "enum",
                            "name": "#rsem-calculate-expression.cwl/bowtie2_sensitivity_level/bowtie2_sensitivity",
                            "symbols": [
                                "#rsem-calculate-expression.cwl/bowtie2_sensitivity_level/bowtie2_sensitivity/very_fast",
                                "#rsem-calculate-expression.cwl/bowtie2_sensitivity_level/bowtie2_sensitivity/fast",
                                "#rsem-calculate-expression.cwl/bowtie2_sensitivity_level/bowtie2_sensitivity/sensitive",
                                "#rsem-calculate-expression.cwl/bowtie2_sensitivity_level/bowtie2_sensitivity/very_sensitive"
                            ]
                        }
                    ],
                    "inputBinding": {
                        "position": 67,
                        "prefix": "--bowtie2-sensitivity-level"
                    },
                    "doc": "(Bowtie 2 parameter) Set Bowtie 2's preset options in --end-to-end mode.\nThis option controls how hard Bowtie 2 tries to find alignments.\n<string| must be one of \"very_fast\", \"fast\", \"sensitive\" and \"very_sensitive\".\nThe four candidates correspond to Bowtie 2's \"--very-fast\", \"--fast\", \"--sensitive\" and \"--very-sensitive\" options.\n(Default: \"sensitive\" - use Bowtie 2's default)\n",
                    "id": "#rsem-calculate-expression.cwl/bowtie2_sensitivity_level"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 71,
                        "prefix": "--bowtie-chunkmbs"
                    },
                    "doc": "(Bowtie parameter) memory allocated for best first alignment calculation\n(Default: 0 - use Bowtie's default)\n",
                    "id": "#rsem-calculate-expression.cwl/bowtie_chunkmbs"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 73,
                        "prefix": "--bowtie-e"
                    },
                    "doc": "(Bowtie parameter) max sum of mismatch quality scores across the alignment.\n(Default: 99999999)\n",
                    "id": "#rsem-calculate-expression.cwl/bowtie_e"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 72,
                        "prefix": "--bowtie-m"
                    },
                    "doc": "(Bowtie parameter) suppress all alignments for a read if | <int| valid alignments exist.\n(Default: 200)\n",
                    "id": "#rsem-calculate-expression.cwl/bowtie_m"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 74,
                        "prefix": "--bowtie-n"
                    },
                    "doc": "(Bowtie parameter) max # of mismatches in the seed.\n(Range: 0-3, Default: 2))\n",
                    "id": "#rsem-calculate-expression.cwl/bowtie_n"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 87,
                        "prefix": "--calc-ci"
                    },
                    "doc": "Calculate 95% credibility intervals and posterior mean estimates.\nThe credibility level can be changed by setting '--ci-credibility-level'.\n(Default: off)\n",
                    "id": "#rsem-calculate-expression.cwl/calc_ci"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 88,
                        "prefix": "--calc-pme"
                    },
                    "doc": "Run RSEM's collapsed Gibbs sampler to calculate posterior mean estimates.\n(Default: off)\n",
                    "id": "#rsem-calculate-expression.cwl/calc_pme"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 40,
                        "prefix": "--cap-stacked-chipseq-reads"
                    },
                    "doc": "Keep a maximum number of ChIP-seq reads that aligned to the same genomic interval.\nThis option is used when running prior-enhanced RSEM, where prior is learned from multiple\ncomplementary data sets. This option is only in use when either '--chipseq-read-files-multi-targets\n<string|' or '--chipseq-bed-files-multi-targets <string|' is specified.\n(Default: off)\n",
                    "id": "#rsem-calculate-expression.cwl/cap_stacked_chipseq_reads"
                },
                {
                    "type": [
                        "null",
                        "File",
                        {
                            "type": "array",
                            "items": "File"
                        }
                    ],
                    "inputBinding": {
                        "position": 41,
                        "itemSeparator": ",",
                        "prefix": "--chipseq-bed-files-multi-targets"
                    },
                    "doc": "Comma-separated full path of BED files for multiple ChIP-seq targets.\nThis option is used when running prior-enhanced RSEM, where prior is learned\nfrom multiple complementary data sets. It provides information of ChIP-seq signals\nand must have at least the first six BED columns. All files can be either\nungzipped or gzipped with a suffix '.gz' or '.gzip'. When this option is specified,\nthe option '--partition-model <string|' will be set to 'cmb_lgt' automatically.\n(Default: \"\")\n",
                    "id": "#rsem-calculate-expression.cwl/chipseq_bed_files_multi_targets"
                },
                {
                    "type": [
                        "null",
                        "File",
                        {
                            "type": "array",
                            "items": "File"
                        }
                    ],
                    "inputBinding": {
                        "position": 43,
                        "itemSeparator": ",",
                        "prefix": "--chipseq-control-read-files"
                    },
                    "doc": "Comma-separated full path of FASTQ read file(s) for ChIP-seq conrol. This option is used when running prior-enhanced RSEM.\nIt provides information to call ChIP-seq peaks. The file(s) can be either ungzipped or gzipped with a suffix\n'.gz' or '.gzip'. The options '--bowtie-path <path|' and '--chipseq-target-read-files <string|'\nmust be defined when this option is specified.\n(Default: \"\")\n",
                    "id": "#rsem-calculate-expression.cwl/chipseq_control_read_files"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "inputBinding": {
                        "position": 45,
                        "prefix": "--chipseq-peak-file"
                    },
                    "doc": "Full path to a ChIP-seq peak file in ENCODE's narrowPeak, i.e. BED6+4, format.\nThis file is used when running prior-enhanced RSEM in the default two-partition model.\nIt partitions isoforms by whether they have ChIP-seq overlapping with their transcription start site region or not.\nEach partition will have its own prior parameter learned from a training set.\nThis file can be either gzipped or ungzipped.\n(Default: \"\")\n",
                    "id": "#rsem-calculate-expression.cwl/chipseq_peak_file"
                },
                {
                    "type": [
                        "null",
                        "File",
                        {
                            "type": "array",
                            "items": "File"
                        }
                    ],
                    "inputBinding": {
                        "position": 42,
                        "itemSeparator": ",",
                        "prefix": "--chipseq-read-files-multi-targets"
                    },
                    "doc": "Comma-separated full path of FASTQ read files for multiple ChIP-seq targets.\nThis option is used when running prior-enhanced RSEM, where prior is learned from multiple\ncomplementary data sets. It provides information to calculate ChIP-seq signals.\nAll files can be either ungzipped or gzipped with a suffix '.gz' or '.gzip'.\nWhen this option is specified, the option '--bowtie-path <path|' must be defined and the option\n'--partition-model <string|' will be set to 'cmb_lgt' automatically.\n(Default: \"\")\n",
                    "id": "#rsem-calculate-expression.cwl/chipseq_read_files_multi_targets"
                },
                {
                    "type": [
                        "null",
                        "File",
                        {
                            "type": "array",
                            "items": "File"
                        }
                    ],
                    "inputBinding": {
                        "position": 44,
                        "itemSeparator": ",",
                        "prefix": "--chipseq-target-read-files"
                    },
                    "doc": "Comma-separated full path of FASTQ read file(s) for ChIP-seq target.\nThis option is used when running prior-enhanced RSEM. It provides information to calculate ChIP-seq peaks and signals.\nThe file(s) can be either ungzipped or gzipped with a suffix '.gz' or '.gzip'. The options '--bowtie-path <path|' and\n'--chipseq-control-read-files <string|' must be defined when this option is specified.\n(Default: \"\")\n",
                    "id": "#rsem-calculate-expression.cwl/chipseq_target_read_files"
                },
                {
                    "type": [
                        "null",
                        "double"
                    ],
                    "inputBinding": {
                        "position": 52,
                        "prefix": "--ci-credibility-level"
                    },
                    "doc": "The credibility level for credibility intervals.\n(Default: 0.95)\n",
                    "id": "#rsem-calculate-expression.cwl/ci_credibility_level"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 51,
                        "prefix": "--ci-memory"
                    },
                    "doc": "Maximum size (in memory, MB) of the auxiliary buffer used for computing credibility intervals (CI).\n(Default: 1024)\n",
                    "id": "#rsem-calculate-expression.cwl/ci_memory"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 50,
                        "prefix": "--ci-number-of-samples-per-count-vector"
                    },
                    "doc": "The number of read generating probability vectors sampled per sampled count vector.\nThe crebility intervals are calculated by first sampling P(C | D) and then sampling P(Theta | C)\nfor each sampled count vector. This option controls how many Theta vectors are sampled per sampled count vector.\n(Default: 50)\n",
                    "id": "#rsem-calculate-expression.cwl/ci_number_of_samples_per_count_vector"
                },
                {
                    "type": [
                        "null",
                        "File",
                        {
                            "type": "array",
                            "items": "File"
                        }
                    ],
                    "inputBinding": {
                        "position": 101,
                        "itemSeparator": ","
                    },
                    "doc": "Comma-separated list of files containing downstream reads\nwhich are paired with the upstream reads.\nBy default, these files are assumed to be in FASTQ format.\nIf the --no-qualities option is specified,\nthen FASTA format is expected.\n",
                    "id": "#rsem-calculate-expression.cwl/downstream_read_file"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 57,
                        "prefix": "--estimate-rspd"
                    },
                    "doc": "Set this option if you want to estimate the read start position distribution (RSPD) from data. Otherwise, RSEM will use a uniform RSPD.\n(Default: off)\n",
                    "id": "#rsem-calculate-expression.cwl/estimate_rspd"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "inputBinding": {
                        "position": 94,
                        "prefix": "--fai"
                    },
                    "doc": "If the header section of input alignment file does not contain reference sequence information,\nthis option should be turned on. <file| is a FAI format file containing each reference sequence's name and length.\nPlease refer to the SAM official website for the details of FAI format.\n(Default: off)\n",
                    "id": "#rsem-calculate-expression.cwl/fai_file"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 60,
                        "prefix": "--fragment-length-max"
                    },
                    "doc": "Maximum read/insert length allowed. This is also the value for the Bowtie/Bowtie 2 -X option.\n(Default: 1000)\n",
                    "id": "#rsem-calculate-expression.cwl/fragment_length_max"
                },
                {
                    "type": [
                        "null",
                        "double"
                    ],
                    "inputBinding": {
                        "position": 59,
                        "prefix": "--fragment-length-mean"
                    },
                    "doc": "(single-end data only) The mean of the fragment length distribution, which is assumed to be a Gaussian.\n(Default: -1, which disables use of the fragment length distribution)\n",
                    "id": "#rsem-calculate-expression.cwl/fragment_length_mean"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 61,
                        "prefix": "--fragment-length-min"
                    },
                    "doc": "Minimum read/insert length allowed. This is also the value for the Bowtie/Bowtie2 -I option.\n(Default: 1)\n",
                    "id": "#rsem-calculate-expression.cwl/fragment_length_min"
                },
                {
                    "type": [
                        "null",
                        "double"
                    ],
                    "inputBinding": {
                        "position": 58,
                        "prefix": "--fragment-length-sd"
                    },
                    "doc": "(single-end data only) The standard deviation of the fragment length distribution, which is assumed to be a Gaussian.\n(Default: 0, which assumes that all fragments are of the same length, given by the rounded value of --fragment-length-mean)\n",
                    "id": "#rsem-calculate-expression.cwl/fragment_length_sd"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 55,
                        "prefix": "--gibbs-burnin"
                    },
                    "doc": "The number of burn-in rounds for RSEM's Gibbs sampler. Each round passes over the entire data set once.\nIf RSEM can use multiple threads, multiple Gibbs samplers will start at the same time and all samplers share the same burn-in number.\n(Default: 200)\n",
                    "id": "#rsem-calculate-expression.cwl/gibbs_burnin"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 54,
                        "prefix": "--gibbs-number-of-samples"
                    },
                    "doc": "TThe total number of count vectors RSEM will collect from its Gibbs samplers.\n(Default: 1000)\n",
                    "id": "#rsem-calculate-expression.cwl/gibbs_number_of_samples"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 53,
                        "prefix": "--gibbs-sampling-gap"
                    },
                    "doc": "The number of rounds between two succinct count vectors RSEM collects.\nIf the count vector after round N is collected, the count vector after round N + <int| will also be collected.\n(Default: 1)\n",
                    "id": "#rsem-calculate-expression.cwl/gibbs_sampling_gap"
                },
                {
                    "type": "Directory",
                    "doc": "Path to the folder where all rsem reference files are saved\n",
                    "id": "#rsem-calculate-expression.cwl/indices_folder"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "inputBinding": {
                        "position": 102,
                        "prefix": "--alignments"
                    },
                    "doc": "SAM/BAM/CRAM formatted input file.\nRSEM requires all alignments of the same read group together.\nFor paired-end reads, RSEM also requires the two mates of any alignment be adjacent.\nIn addition, RSEM does not allow the SEQ and QUAL fields to be empty.\nSee Description section for how to make input file obey RSEM's requirements.\n",
                    "id": "#rsem-calculate-expression.cwl/input_aligned"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 49,
                        "prefix": "--keep-intermediate-files"
                    },
                    "doc": "Keep temporary files generated by RSEM. RSEM creates a temporary directory, 'sample_name.temp', into which\nit puts all intermediate output files. If this directory already exists, RSEM overwrites all files generated\nby previous RSEM runs inside of it. By default, after RSEM finishes, the temporary directory is deleted.\nSet this option to prevent the deletion of this directory and the intermediate files inside of it.\n(Default: off)\n",
                    "id": "#rsem-calculate-expression.cwl/keep_intermediate_files"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 39,
                        "prefix": "--n-max-stacked-chipseq-reads"
                    },
                    "doc": "The maximum number of stacked ChIP-seq reads to keep. This option is used when running prior-enhanced RSEM,\nwhere prior is learned from multiple complementary data sets. This option is only in use when the option\n'--cap-stacked-chipseq-reads' is set.\n(Default: 5)\n",
                    "id": "#rsem-calculate-expression.cwl/n_max_stacked_chipseq_reads"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 84,
                        "prefix": "--no-bam-output"
                    },
                    "doc": "Do not output any BAM file.\n(Default: off)\n",
                    "id": "#rsem-calculate-expression.cwl/no_bam_output"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 97,
                        "prefix": "--no-qualities"
                    },
                    "doc": "Input reads do not contain quality scores\n(Default: off)\n",
                    "id": "#rsem-calculate-expression.cwl/no_qualities"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 56,
                        "prefix": "--num-rspd-bins"
                    },
                    "doc": "Number of bins in the RSPD. Only relevant when '--estimate-rspd' is specified. Use of the default setting is recommended.\n(Default: 20)\n",
                    "id": "#rsem-calculate-expression.cwl/num_rspd_bins"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "inputBinding": {
                        "position": 104,
                        "valueFrom": "${\n    if (self == \"\"){\n      return default_output_filename();\n    } else {\n      return self;\n    }\n}\n"
                    },
                    "default": "",
                    "doc": "The name of the sample analyzed.\nAll output files are prefixed by this name\n(e.g., sample_name.genes.results)\n",
                    "id": "#rsem-calculate-expression.cwl/output_filename"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 82,
                        "prefix": "--output-genome-bam"
                    },
                    "doc": "Generate a BAM file, 'sample_name.genome.bam', with alignments mapped to genomic coordinates and annotated with\ntheir posterior probabilities. In addition, RSEM will call samtools (included in RSEM package) to sort and index\nthe bam file. 'sample_name.genome.sorted.bam' and 'sample_name.genome.sorted.bam.bai' will be generated.\n(Default: off)\n",
                    "id": "#rsem-calculate-expression.cwl/output_genome_bam"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 99,
                        "prefix": "--paired-end"
                    },
                    "doc": "Input reads are paired-end reads\nIf ommited and both upstream_read_file and downstream_read_file are set - we'll add this prefix\nautomatically from the arguments oprator.\nIn a case of using input 'input', user should define himself either it's paired-end or single-end data\n(Default: off)\n",
                    "id": "#rsem-calculate-expression.cwl/paired_end"
                },
                {
                    "type": [
                        "null",
                        {
                            "type": "enum",
                            "name": "#rsem-calculate-expression.cwl/partition_model/partition_model",
                            "symbols": [
                                "#rsem-calculate-expression.cwl/partition_model/partition_model/pk",
                                "#rsem-calculate-expression.cwl/partition_model/partition_model/pk_lgtnopk",
                                "#rsem-calculate-expression.cwl/partition_model/partition_model/lm3",
                                "#rsem-calculate-expression.cwl/partition_model/partition_model/lm4",
                                "#rsem-calculate-expression.cwl/partition_model/partition_model/lm5",
                                "#rsem-calculate-expression.cwl/partition_model/partition_model/lm6",
                                "#rsem-calculate-expression.cwl/partition_model/partition_model/nopk_lm2pk",
                                "#rsem-calculate-expression.cwl/partition_model/partition_model/nopk_lm3pk",
                                "#rsem-calculate-expression.cwl/partition_model/partition_model/nopk_lm4pk",
                                "#rsem-calculate-expression.cwl/partition_model/partition_model/nopk_lm5pk",
                                "#rsem-calculate-expression.cwl/partition_model/partition_model/pk_lm2nopk",
                                "#rsem-calculate-expression.cwl/partition_model/partition_model/pk_lm3nopk",
                                "#rsem-calculate-expression.cwl/partition_model/partition_model/pk_lm4nopk",
                                "#rsem-calculate-expression.cwl/partition_model/partition_model/pk_lm5nopk",
                                "#rsem-calculate-expression.cwl/partition_model/partition_model/cmb_lgt"
                            ]
                        }
                    ],
                    "inputBinding": {
                        "position": 38,
                        "prefix": "--partition-model"
                    },
                    "doc": "A keyword to specify the partition model used by prior-enhanced RSEM. It must be one of the following keywords:\n- pk\n    Partitioned by whether an isoform has a ChIP-seq peak overlapping with its transcription start site (TSS) region.\n    The TSS region is defined as [TSS-500bp, TSS+500bp]. For simplicity, we refer this type of peak as 'TSS peak'\n    when explaining other keywords.\n- pk_lgtnopk\n    First partitioned by TSS peak. Then, for isoforms in the 'no TSS peak' set, a logistic model is employed to\n    further classify them into two partitions.\n- lm3, lm4, lm5, or lm6\n    Based on their ChIP-seq signals, isoforms are classified into 3, 4, 5, or 6 partitions by a linear regression model.\n- nopk_lm2pk, nopk_lm3pk, nopk_lm4pk, or nopk_lm5pk\n    First partitioned by TSS peak. Then, for isoforms in the 'with TSS peak' set, a linear regression model is\n    employed to further classify them into 2, 3, 4, or 5 partitions.\n- pk_lm2nopk, pk_lm3nopk, pk_lm4nopk, or pk_lm5nopk\n    First partitioned by TSS peak. Then, for isoforms in the 'no TSS peak' set, a linear regression model is\n    employed to further classify them into 2, 3, 4, or 5 partitions.\n- cmb_lgt\n    Using a logistic regression to combine TSS signals from multiple complementary data sets and partition training\n    set isoform into 'expressed' and 'not expressed'. This partition model is only in use when either '--chipseq-read-files-multi-targets <string|' or '--chipseq-bed-files-multi-targets <string| is specified.\n\nParameters for all the above models are learned from a training set. For detailed explainations,\nplease see prior-enhanced RSEM's paper.\n(Default: 'pk')\n",
                    "id": "#rsem-calculate-expression.cwl/partition_model"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 78,
                        "prefix": "--phred33-quals"
                    },
                    "doc": "Input quality scores are encoded as Phred+33.\n(Default: on)\n",
                    "id": "#rsem-calculate-expression.cwl/phred33_quals"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 77,
                        "prefix": "--phred64-quals"
                    },
                    "doc": "Input quality scores are encoded as Phred+64 (default for GA Pipeline ver. |= 1.3).\n(Default: off)\n",
                    "id": "#rsem-calculate-expression.cwl/phred64_quals"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 86,
                        "prefix": "--quiet"
                    },
                    "doc": "Suppress the output of logging information.\n(Default: off)\n",
                    "id": "#rsem-calculate-expression.cwl/quiet"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 46,
                        "prefix": "--run-pRSEM"
                    },
                    "doc": "Running prior-enhanced RSEM (pRSEM). Prior parameters, i.e. isoform's initial pseudo-count for RSEM's Gibbs sampling,\nwill be learned from input RNA-seq data and an external data set. When pRSEM needs and only needs ChIP-seq peak\ninformation to partition isoforms (e.g. in pRSEM's default partition model), either ChIP-seq peak file (with the\n'--chipseq-peak-file' option) or ChIP-seq FASTQ files for target and input and the path for Bowtie executables\nare required (with the '--chipseq-target-read-files <string|', '--chipseq-control-read-files <string|', and\n'--bowtie-path <path| options), otherwise, ChIP-seq FASTQ files for target and control and the path to\nBowtie executables are required.\n(Default: off)\n",
                    "id": "#rsem-calculate-expression.cwl/run_prsem"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 83,
                        "prefix": "--sampling-for-bam"
                    },
                    "doc": "When RSEM generates a BAM file, instead of outputting all alignments a read has with their posterior probabilities,\none alignment is sampled according to the posterior probabilities. The sampling procedure includes the alignment\nto the \"noise\" transcript, which does not appear in the BAM file. Only the sampled alignment has a weight of 1.\nAll other alignments have weight 0. If the \"noise\" transcript is sampled, all alignments appeared in the BAM file\nshould have weight 0.\n(Default: off)\n",
                    "id": "#rsem-calculate-expression.cwl/sampling_for_bam"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 90,
                        "prefix": "--seed"
                    },
                    "doc": "Set the seed for the random number generators used in calculating posterior mean estimates and credibility intervals.\nThe seed must be a non-negative 32 bit integer.\n(Default: off)\n",
                    "id": "#rsem-calculate-expression.cwl/seed"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 79,
                        "prefix": "--seed-length"
                    },
                    "doc": "Seed length used by the read aligner. Providing the correct value is important for RSEM.\nIf RSEM runs Bowtie, it uses this value for Bowtie's seed length parameter.\nAny read with its or at least one of its mates' (for paired-end reads) length less than this value will be ignored.\nIf the references are not added poly(A) tails, the minimum allowed value is 5, otherwise, the minimum allowed value is 25.\nNote that this script will only check if the value |= 5 and give a warning message if the value < 25 but |= 5.\n(Default: 25)\n",
                    "id": "#rsem-calculate-expression.cwl/seed_length"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 89,
                        "prefix": "--single-cell-prior"
                    },
                    "doc": "By default, RSEM uses Dirichlet(1) as the prior to calculate posterior mean estimates and credibility intervals.\nHowever, much less genes are expressed in single cell RNA-Seq data. Thus, if you want to compute posterior\nmean estimates and/or credibility intervals and you have single-cell RNA-Seq data, you are recommended\nto turn on this option. Then RSEM will use Dirichlet(0.1) as the prior which encourage the sparsity\nof the expression levels.\n(Default: off)\n",
                    "id": "#rsem-calculate-expression.cwl/single_cell_prior"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 76,
                        "prefix": "--solexa-quals"
                    },
                    "doc": "Input quality scores are solexa encoded (from GA Pipeline ver. < 1.3).\n(Default: off)\n",
                    "id": "#rsem-calculate-expression.cwl/solexa_quals"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 81,
                        "prefix": "--sort-bam-by-coordinate"
                    },
                    "doc": "Sort RSEM generated transcript and genome BAM files by coordinates and build associated indices.\n(Default: off)\n",
                    "id": "#rsem-calculate-expression.cwl/sort_bam_by_coordinate"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 85,
                        "prefix": "--sort-bam-by-read-name"
                    },
                    "doc": "Sort BAM file aligned under transcript coordidate by read name.\nSetting this option on will produce deterministic maximum likelihood estimations from independent runs.\nNote that sorting will take long time and lots of memory.\n(Default: off)\n",
                    "id": "#rsem-calculate-expression.cwl/sort_bam_by_read_name"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "inputBinding": {
                        "position": 80,
                        "prefix": "--sort-bam-memory-per-thread"
                    },
                    "doc": "Set the maximum memory per thread that can be used by 'samtools sort'. <string| represents the memory and accepts\nsuffices 'K/M/G'. RSEM will pass <string| to the '-m' option of 'samtools sort'.\nNote that the default used here is different from the default used by samtools.\n(Default: 1G)\n",
                    "id": "#rsem-calculate-expression.cwl/sort_bam_memory_per_thread"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 92,
                        "prefix": "--star"
                    },
                    "doc": "Use STAR to align reads. Alignment parameters are from ENCODE3's STAR-RSEM pipeline.\nTo save computational time and memory resources, STAR's Output BAM file is unsorted.\nIt is stored in RSEM's temporary directory with name as 'sample_name.bam'.\nEach STAR job will have its own private copy of the genome in memory. (Default: off)\n",
                    "id": "#rsem-calculate-expression.cwl/star"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 64,
                        "prefix": "--star-bzipped-read-file"
                    },
                    "doc": "(STAR parameter) Input read file(s) is compressed by bzip2.\n(Default: off)\n",
                    "id": "#rsem-calculate-expression.cwl/star_bzipped_read_file"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 65,
                        "prefix": "--star-gzipped-read-file"
                    },
                    "doc": "(STAR parameter) Input read file(s) is compressed by gzip.\n(Default: off)\n",
                    "id": "#rsem-calculate-expression.cwl/star_gzipped_read_file"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 63,
                        "prefix": "--star-output-genome-bam"
                    },
                    "doc": "(STAR parameter) Save the BAM file from STAR alignment under genomic coordinate to 'sample_name.STAR.genome.bam'.\nThis file is NOT sorted by genomic coordinate. In this file, according to STAR's manual,\n'paired ends of an alignment are always adjacent, and multiple alignments of a read are adjacent as well'.\n(Default: off)\n",
                    "id": "#rsem-calculate-expression.cwl/star_output_genome_bam"
                },
                {
                    "type": [
                        "null",
                        {
                            "type": "enum",
                            "name": "#rsem-calculate-expression.cwl/strandedness/strandedness",
                            "symbols": [
                                "#rsem-calculate-expression.cwl/strandedness/strandedness/none",
                                "#rsem-calculate-expression.cwl/strandedness/strandedness/forward",
                                "#rsem-calculate-expression.cwl/strandedness/strandedness/reverse"
                            ]
                        }
                    ],
                    "inputBinding": {
                        "position": 96,
                        "prefix": "--strandedness"
                    },
                    "doc": "This option defines the strandedness of the RNA-Seq reads.\nIt recognizes three values: 'none', 'forward', and 'reverse'.\n'none' refers to non-strand-specific protocols.\n'forward' means all (upstream) reads are derived from the forward strand.\n'reverse' means all (upstream) reads are derived from the reverse strand.\nIf 'forward'/'reverse' is set, the '--norc'/'--nofw' Bowtie/Bowtie 2 option\nwill also be enabled to avoid aligning reads to the opposite strand.\nFor Illumina TruSeq Stranded protocols, please use 'reverse'.\n(Default: 'none')\n",
                    "id": "#rsem-calculate-expression.cwl/strandedness"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "inputBinding": {
                        "position": 62,
                        "prefix": "--tag"
                    },
                    "doc": "The name of the optional field used in the SAM input for identifying a read with too many valid alignments.\nThe field should have the format <tagName|:i:<value|, where a <value| bigger than 0 indicates a read with too many alignments.\n(Default: \"\")\n",
                    "id": "#rsem-calculate-expression.cwl/tag"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "inputBinding": {
                        "position": 48,
                        "prefix": "--temporary-folder"
                    },
                    "doc": "Set where to put the temporary files generated by RSEM.\nIf the folder specified does not exist, RSEM will try to create it.\n(Default: sample_name.temp)\n",
                    "id": "#rsem-calculate-expression.cwl/temporary_folder"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 95,
                        "prefix": "--num-threads"
                    },
                    "doc": "Number of threads to use. Both Bowtie/Bowtie2, expression estimation and 'samtools sort' will use this many threads.\n(Default: 1)\n",
                    "id": "#rsem-calculate-expression.cwl/threads"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 47,
                        "prefix": "--time"
                    },
                    "doc": "Output time consumed by each step of RSEM to 'sample_name.time'.\n(Default: off)\n",
                    "id": "#rsem-calculate-expression.cwl/time"
                },
                {
                    "type": [
                        "null",
                        "File",
                        {
                            "type": "array",
                            "items": "File"
                        }
                    ],
                    "inputBinding": {
                        "position": 100
                    },
                    "doc": "Comma-separated list of files containing single-end reads\nor upstream reads for paired-end data.\nBy default, these files are assumed to be in FASTQ format.\nIf the --no-qualities option is specified,\nthen FASTA format is expected.\n",
                    "id": "#rsem-calculate-expression.cwl/upstream_read_file"
                }
            ],
            "outputs": [
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputBinding": {
                        "glob": "${\n    if (inputs.output_filename == \"\"){\n      return default_output_filename() + \".time\";\n    } else {\n      return inputs.output_filename + \".time\";\n    }\n}\n"
                    },
                    "id": "#rsem-calculate-expression.cwl/align_time_file"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputBinding": {
                        "glob": "${\n    if (inputs.output_filename == \"\"){\n      return default_output_filename() + \".alleles.results\";\n    } else {\n      return inputs.output_filename + \".alleles.results\";\n    }\n}\n"
                    },
                    "id": "#rsem-calculate-expression.cwl/alleles_results_file"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputBinding": {
                        "glob": "${\n    if (inputs.output_filename == \"\"){\n      return default_output_filename() + \".genes.results\";\n    } else {\n      return inputs.output_filename + \".genes.results\";\n    }\n}\n"
                    },
                    "id": "#rsem-calculate-expression.cwl/gene_results_file"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputBinding": {
                        "glob": "${\n    if (inputs.output_filename == \"\"){\n      return default_output_filename() + \".genome.bam\";\n    } else {\n      return inputs.output_filename + \".genome.bam\";\n    }\n}\n"
                    },
                    "id": "#rsem-calculate-expression.cwl/genome_bam_file"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputBinding": {
                        "glob": "${\n    if (inputs.output_filename == \"\"){\n      return default_output_filename() + \".genome.sorted.bam\";\n    } else {\n      return inputs.output_filename + \".genome.sorted.bam\";\n    }\n}\n"
                    },
                    "secondaryFiles": "${return self.basename + \".bai\"}",
                    "id": "#rsem-calculate-expression.cwl/genome_sorted_bam_bai_pair"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputBinding": {
                        "glob": "${\n    if (inputs.output_filename == \"\"){\n      return default_output_filename() + \".isoforms.results\";\n    } else {\n      return inputs.output_filename + \".isoforms.results\";\n    }\n}\n"
                    },
                    "id": "#rsem-calculate-expression.cwl/isoform_results_file"
                },
                {
                    "type": "int",
                    "outputBinding": {
                        "loadContents": true,
                        "glob": "${\n    if (inputs.output_filename == \"\"){\n      return default_output_filename() + \".stat/\" + default_output_filename() + \".cnt\";\n    } else {\n      return inputs.output_filename + \".stat/\" + inputs.output_filename + \".cnt\";\n    }\n}\n",
                        "outputEval": "${\n  return parseInt(self[0].contents.split(/\\r?\\n/)[0].split(\" \")[1]);\n}\n"
                    },
                    "id": "#rsem-calculate-expression.cwl/mapped_reads_number"
                },
                {
                    "type": "int",
                    "outputBinding": {
                        "loadContents": true,
                        "glob": "${\n    if (inputs.output_filename == \"\"){\n      return default_output_filename() + \".stat/\" + default_output_filename() + \".cnt\";\n    } else {\n      return inputs.output_filename + \".stat/\" + inputs.output_filename + \".cnt\";\n    }\n}\n",
                        "outputEval": "${\n  return parseInt(self[0].contents.split(/\\r?\\n/)[0].split(\" \")[2]);\n}\n"
                    },
                    "id": "#rsem-calculate-expression.cwl/multimapped_reads_number"
                },
                {
                    "type": "Directory",
                    "outputBinding": {
                        "glob": "${\n    if (inputs.output_filename == \"\"){\n      return default_output_filename() + \".stat\";\n    } else {\n      return inputs.output_filename + \".stat\";\n    }\n}\n"
                    },
                    "id": "#rsem-calculate-expression.cwl/stat_folder"
                },
                {
                    "type": "int",
                    "outputBinding": {
                        "loadContents": true,
                        "glob": "${\n    if (inputs.output_filename == \"\"){\n      return default_output_filename() + \".stat/\" + default_output_filename() + \".cnt\";\n    } else {\n      return inputs.output_filename + \".stat/\" + inputs.output_filename + \".cnt\";\n    }\n}\n",
                        "outputEval": "${\n  return parseInt(self[0].contents.split(/\\r?\\n/)[0].split(\" \")[3]);\n}\n"
                    },
                    "id": "#rsem-calculate-expression.cwl/total_reads_number"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputBinding": {
                        "glob": "${\n    if (inputs.output_filename == \"\"){\n      return default_output_filename() + \".transcript.bam\";\n    } else {\n      return inputs.output_filename + \".transcript.bam\";\n    }\n}\n"
                    },
                    "id": "#rsem-calculate-expression.cwl/transcript_bam_file"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputBinding": {
                        "glob": "${\n    if (inputs.output_filename == \"\"){\n      return default_output_filename() + \".transcript.sorted.bam\";\n    } else {\n      return inputs.output_filename + \".transcript.sorted.bam\";\n    }\n}\n"
                    },
                    "secondaryFiles": "${return self.basename + \".bai\"}",
                    "id": "#rsem-calculate-expression.cwl/transcript_sorted_bam_bai_pair"
                },
                {
                    "type": "int",
                    "outputBinding": {
                        "loadContents": true,
                        "glob": "${\n    if (inputs.output_filename == \"\"){\n      return default_output_filename() + \".stat/\" + default_output_filename() + \".cnt\";\n    } else {\n      return inputs.output_filename + \".stat/\" + inputs.output_filename + \".cnt\";\n    }\n}\n",
                        "outputEval": "${\n  return parseInt(self[0].contents.split(/\\r?\\n/)[0].split(\" \")[0]);\n}\n"
                    },
                    "id": "#rsem-calculate-expression.cwl/unmapped_reads_number"
                }
            ],
            "baseCommand": [
                "rsem-calculate-expression"
            ],
            "arguments": [
                {
                    "valueFrom": "${\n  if (inputs.upstream_read_file && inputs.downstream_read_file && !inputs.paired_end){\n    return \"--paired-end\";\n  }\n  return null;\n}\n",
                    "position": 99
                },
                {
                    "valueFrom": "${\n    for (var i = 0; i < inputs.indices_folder.listing.length; i++) {\n        if (inputs.indices_folder.listing[i].basename.split('.').slice(-1)[0] == 'grp'){\n          let name = inputs.indices_folder.listing[i].basename.split('.').slice(0,-1).join('.');\n          return inputs.indices_folder.listing[i].path.split('/').slice(0,-1).join('/') + '/' + name;\n        }\n    }\n    return null;\n}\n",
                    "position": 103
                }
            ],
            "doc": "Tool runs rsem-calculate-expression.\n\n`reference_name` parameter for RSEM is resolved from `indices_folder` input.\nIf `paired_end` input is not set, but both of the `upstream_read_file` and `downstream_read_file` are present,\nset `paired_end` automatically.\n\n`default_output_filename` function return prefix fot output files generated by RSEM based on `upstream_read_file` or\n`downstream_read_file` basename, if `output_filename` input is not provided\n",
            "id": "#rsem-calculate-expression.cwl",
            "http://schema.org/name": "rsem-calculate-expression",
            "http://schema.org/downloadUrl": "https://raw.githubusercontent.com/Barski-lab/workflows/master/tools/rsem-calculate-expression.cwl",
            "http://schema.org/codeRepository": "https://github.com/Barski-lab/workflows",
            "http://schema.org/license": "http://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/isPartOf": {
                "class": "http://schema.org/CreativeWork",
                "http://schema.org/name": "Common Workflow Language",
                "http://schema.org/url": "http://commonwl.org/"
            },
            "http://schema.org/mainEntity": {
                "class": "http://schema.org/SoftwareSourceCode",
                "id": "#rsem-metadata.yaml",
                "http://schema.org/name": "rsem",
                "http://schema.org/about": "RSEM is a software package for estimating gene and isoform expression levels from RNA-Seq data.\nThe RSEM package provides an user-friendly interface, supports threads for parallel computation of the EM algorithm,\nsingle-end and paired-end read data, quality scores, variable-length reads and RSPD estimation.\nIn addition, it provides posterior mean and 95% credibility interval estimates for expression levels.\nFor visualization, It can generate BAM and Wiggle files in both transcript-coordinate and genomic-coordinate.\nGenomic-coordinate files can be visualized by both UCSC Genome browser and Broad Institute\u2019s Integrative Genomics\nViewer (IGV). Transcript-coordinate files can be visualized by IGV. RSEM also has its own scripts to generate\ntranscript read depth plots in pdf format. The unique feature of RSEM is, the read depth plots can be stacked,\nwith read depth contributed to unique reads shown in black and contributed to multi-reads shown in red.\nIn addition, models learned from data can also be visualized. Last but not least, RSEM contains a simulator.\n",
                "http://schema.org/url": "http://deweylab.github.io/RSEM/",
                "http://schema.org/codeRepository": "https://github.com/deweylab/RSEM",
                "http://schema.org/license": [
                    "https://opensource.org/licenses/GPL-3.0"
                ],
                "http://schema.org/targetProduct": {
                    "class": "http://schema.org/SoftwareApplication",
                    "http://schema.org/softwareVersion": "1.3.0",
                    "http://schema.org/applicationCategory": "command line tool"
                },
                "http://schema.org/programmingLanguage": "C++",
                "http://schema.org/publication": [
                    {
                        "class": "http://schema.org/ScholarlyArticle",
                        "id": "#rsem-metadata.yaml/10.1186/1471-2105-12-323",
                        "datePublished": "4 August 2011",
                        "http://schema.org/name": "RSEM: accurate transcript quantification from RNA-Seq data with or without a reference genome. BMC Bioinformatics",
                        "http://schema.org/author": [
                            {
                                "class": "http://schema.org/Person",
                                "http://schema.org/name": "Bo Li"
                            },
                            {
                                "class": "http://schema.org/Person",
                                "http://schema.org/name": "Colin N Dewey"
                            }
                        ],
                        "http://schema.org/url": "http://bmcbioinformatics.biomedcentral.com/articles/10.1186/1471-2105-12-323"
                    }
                ],
                "http://schema.org/discussionUrl": [
                    "https://groups.google.com/forum/#!forum/rsem-users",
                    "https://groups.google.com/forum/#!forum/rsem-announce"
                ],
                "http://schema.org/creator": [
                    {
                        "class": "http://schema.org/Organization",
                        "http://schema.org/name": "University of California at Berkeley",
                        "http://schema.org/member": [
                            {
                                "class": "http://schema.org/Person",
                                "http://schema.org/name": "Bo Li",
                                "http://schema.org/description": "RSEM software implementation, RSEM algorithm design"
                            }
                        ]
                    },
                    {
                        "class": "http://schema.org/Organization",
                        "http://schema.org/name": "University of Wisconsin-Madison",
                        "http://schema.org/member": [
                            {
                                "class": "http://schema.org/Person",
                                "http://schema.org/name": "Colin N Dewey",
                                "http://schema.org/description": "RSEM algorithm design"
                            }
                        ]
                    }
                ]
            },
            "http://schema.org/creator": [
                {
                    "class": "http://schema.org/Organization",
                    "http://schema.org/legalName": "Cincinnati Children's Hospital Medical Center",
                    "http://schema.org/location": [
                        {
                            "class": "http://schema.org/PostalAddress",
                            "http://schema.org/addressCountry": "USA",
                            "http://schema.org/addressLocality": "Cincinnati",
                            "http://schema.org/addressRegion": "OH",
                            "http://schema.org/postalCode": "45229",
                            "http://schema.org/streetAddress": "3333 Burnet Ave",
                            "http://schema.org/telephone": "+1(513)636-4200"
                        }
                    ],
                    "http://schema.org/logo": "https://www.cincinnatichildrens.org/-/media/cincinnati%20childrens/global%20shared/childrens-logo-new.png",
                    "http://schema.org/department": [
                        {
                            "class": "http://schema.org/Organization",
                            "http://schema.org/legalName": "Allergy and Immunology",
                            "http://schema.org/department": [
                                {
                                    "class": "http://schema.org/Organization",
                                    "http://schema.org/legalName": "Barski Research Lab",
                                    "http://schema.org/member": [
                                        {
                                            "class": "http://schema.org/Person",
                                            "http://schema.org/name": "Michael Kotliar",
                                            "http://schema.org/email": "mailto:misha.kotliar@gmail.com",
                                            "http://schema.org/sameAs": [
                                                {
                                                    "$import": "#0000-0002-6486-3898"
                                                }
                                            ]
                                        }
                                    ]
                                }
                            ]
                        }
                    ]
                }
            ],
            "http://schema.org/about": "Usage:\n   rsem-calculate-expression [options] upstream_read_file(s) reference_name sample_name\n   rsem-calculate-expression [options] --paired-end upstream_read_file(s) downstream_read_file(s) reference_name sample_name\n   rsem-calculate-expression [options] --alignments [--paired-end] input reference_name sample_name\n"
        },
        {
            "class": "CommandLineTool",
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                },
                {
                    "class": "ShellCommandRequirement"
                },
                {
                    "class": "InitialWorkDirRequirement",
                    "listing": "${\n  var listing = []\n  if (inputs.fastq_file_upstream){\n    listing.push(inputs.fastq_file_upstream);\n  }\n  if (inputs.fastq_file_downstream){\n    listing.push(inputs.fastq_file_downstream);\n  }\n  return listing;\n}\n"
                },
                {
                    "class": "InlineJavascriptRequirement",
                    "expressionLib": [
                        "var default_output_filename = function(input_file, ext) { let root = input_file.basename.split('.').slice(0,-1).join('.'); return (root == \"\")?inputs.input_file.basename+ext:root+ext; };"
                    ]
                }
            ],
            "hints": [
                {
                    "class": "DockerRequirement",
                    "dockerPull": "biowardrobe2/trimmomatic:v0.35"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "doc": "FASTA file containing adapters, PCR sequences, etc. It is used to search\nfor and remove these sequences in the input FASTQ file(s)\n",
                    "id": "#trimmomatic.cwl/adapters_file"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "default": "#!/bin/bash\nif [ \"$0\" = \"true\" ]\nthen\n  echo \"Run trimmomatic\"\n  java \"${@:1}\"\nelse\n  echo \"Skip run trimmomatic\"\nfi\n",
                    "inputBinding": {
                        "position": 1
                    },
                    "doc": "Bash function to run trimmomatic with all input parameters or skip it if trigger is false\n",
                    "id": "#trimmomatic.cwl/bash_script"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 104,
                        "prefix": "CROP:",
                        "separate": false
                    },
                    "doc": "<length>\nRemoves bases regardless of quality from the end of the read, so that the read has maximally\nthe specified length after this step has been performed. Steps performed after CROP might of\ncourse further shorten the read.\n<length>: The number of bases to keep, from the start of the read.\n",
                    "id": "#trimmomatic.cwl/crop_step"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "inputBinding": {
                        "position": 14
                    },
                    "doc": "FASTQ file for read R2 in Paired End mode\n",
                    "id": "#trimmomatic.cwl/fastq_file_downstream"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 13
                    },
                    "doc": "FASTQ file for input read (read R1 in Paired End mode)\n",
                    "id": "#trimmomatic.cwl/fastq_file_upstream"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 105,
                        "prefix": "HEADCROP:",
                        "separate": false
                    },
                    "doc": "<length>\nRemoves the specified number of bases, regardless of quality, from the beginning of the read.\n<length>: The number of bases to keep, from the start of the read.\n",
                    "id": "#trimmomatic.cwl/headcrop_step"
                },
                {
                    "type": "string",
                    "doc": "<fastaWithAdaptersEtc>:<seed mismatches>:<palindrome clip threshold>:<simple clip threshold>:<minAdapterLength>:<keepBothReads>\nFind and remove Illumina adapters.\nREQUIRED:\n<fastaWithAdaptersEtc>: specifies the path to a fasta file containing all the adapters, PCR sequences etc.\nThe naming of the various sequences within this file determines how they are used. See below.\n<seedMismatches>: specifies the maximum mismatch count which will still allow a full match to be performed\n<palindromeClipThreshold>: specifies how accurate the match between the two 'adapter ligated' reads must be\nfor PE palindrome read alignment.\n<simpleClipThreshold>: specifies how accurate the match between any adapter etc. sequence must be against a read\nOPTIONAL:\n<minAdapterLength>: In addition to the alignment score, palindrome mode can verify\nthat a minimum length of adapter has been detected. If unspecified, this defaults to 8 bases,\nfor historical reasons. However, since palindrome mode has a very low false positive rate, this\ncan be safely reduced, even down to 1, to allow shorter adapter fragments to be removed.\n<keepBothReads>: After read-though has been detected by palindrome mode, and the\nadapter sequence removed, the reverse read contains the same sequence information as the\nforward read, albeit in reverse complement. For this reason, the default behaviour is to\nentirely drop the reverse read. By specifying \u201etrue\u201f for this parameter, the reverse read will\nalso be retained, which may be useful e.g. if the downstream tools cannot handle a\ncombination of paired and unpaired reads.\n",
                    "id": "#trimmomatic.cwl/illuminaclip_step_param"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "inputBinding": {
                        "position": 6,
                        "shellQuote": false
                    },
                    "doc": "JVM arguments should be a quoted, space separated list (e.g. \"-Xms128m -Xmx512m\")",
                    "id": "#trimmomatic.cwl/java_opts"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 102,
                        "prefix": "LEADING:",
                        "separate": false
                    },
                    "doc": "<quality>\nRemove low quality bases from the beginning. As long as a base has a value below this\nthreshold the base is removed and the next base will be investigated.\n<quality>: Specifies the minimum quality required to keep a base.\n",
                    "id": "#trimmomatic.cwl/leading_step"
                },
                {
                    "type": [
                        {
                            "type": "enum",
                            "name": "#trimmomatic.cwl/lib_type/format",
                            "symbols": [
                                "#trimmomatic.cwl/lib_type/format/SE",
                                "#trimmomatic.cwl/lib_type/format/PE"
                            ]
                        }
                    ],
                    "inputBinding": {
                        "position": 8
                    },
                    "doc": "SE|PE\nSingle End (SE) or Paired End (PE) mode\n",
                    "id": "#trimmomatic.cwl/lib_type"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "inputBinding": {
                        "position": 12,
                        "prefix": "-trimlog"
                    },
                    "doc": "<ouptut log file name>\nSpecifying a trimlog file creates a log of all read trimmings, indicating the following details:\n  the read name\n  the surviving sequence length\n  the location of the first surviving base, aka. the amount trimmed from the start\n  the location of the last surviving base in the original read\n  the amount trimmed from the end\n<ouptut log file name>: filename for the generated output log file.\n",
                    "id": "#trimmomatic.cwl/log_filename"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 106,
                        "prefix": "MINLEN:",
                        "separate": false
                    },
                    "doc": "<length>\nThis module removes reads that fall below the specified minimal length. If required, it should\nnormally be after all other processing steps. Reads removed by this step will be counted and\nincluded in the \u201edropped reads\u201f count presented in the trimmomatic summary.\n<length>:  Specifies the minimum length of reads to be kept\n",
                    "id": "#trimmomatic.cwl/minlen_step"
                },
                {
                    "type": [
                        "null",
                        {
                            "type": "enum",
                            "name": "#trimmomatic.cwl/phred/phred",
                            "symbols": [
                                "#trimmomatic.cwl/phred/phred/33",
                                "#trimmomatic.cwl/phred/phred/64"
                            ]
                        }
                    ],
                    "inputBinding": {
                        "prefix": "-phred",
                        "separate": false,
                        "position": 9
                    },
                    "doc": "\"33\"|\"64\"\n-phred33 (\"33\") or -phred64 (\"64\") specifies the base quality encoding. Default: -phred64\n",
                    "id": "#trimmomatic.cwl/phred"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "inputBinding": {
                        "position": 101,
                        "prefix": "SLIDINGWINDOW:",
                        "separate": false
                    },
                    "doc": "<windowSize>:<requiredQuality>\nPerform a sliding window trimming, cutting once the average quality within the window falls\nbelow a threshold. By considering multiple bases, a single poor quality base will not cause the\nremoval of high quality data later in the read.\n<windowSize>: specifies the number of bases to average across\n<requiredQuality>: specifies the average quality required\n",
                    "id": "#trimmomatic.cwl/sliding_window_step"
                },
                {
                    "type": "int",
                    "default": 1,
                    "inputBinding": {
                        "position": 11,
                        "prefix": "-threads"
                    },
                    "doc": "Number of threads\n",
                    "id": "#trimmomatic.cwl/threads"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 107,
                        "prefix": "TOPHRED33",
                        "separate": false
                    },
                    "doc": "This (re)encodes the quality part of the FASTQ file to base 33.\n",
                    "id": "#trimmomatic.cwl/tophred33_step"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 107,
                        "prefix": "TOPHRED64",
                        "separate": false
                    },
                    "doc": "This (re)encodes the quality part of the FASTQ file to base 64.\n",
                    "id": "#trimmomatic.cwl/tophred64_step"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 103,
                        "prefix": "TRAILING:",
                        "separate": false
                    },
                    "doc": "<quality>\nRemove low quality bases from the end. As long as a base has a value below this threshold\nthe base is removed and the next base (which as trimmomatic is starting from the 3\u201f prime end\nwould be base preceding the just removed base) will be investigated. This approach can be\nused removing the special illumina \u201elow quality segment\u201f regions (which are marked with\nquality score of 2), but we recommend Sliding Window or MaxInfo instead\n<quality>: Specifies the minimum quality required to keep a base.\n",
                    "id": "#trimmomatic.cwl/trailing_step"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "default": true,
                    "inputBinding": {
                        "position": 5,
                        "valueFrom": "${ return self ? \"true\" : \"false\" }\n"
                    },
                    "doc": "If true - run trimmomatic, if false - return input fastq files, previously staged into output directory.\nUse valueFrom to return string instead of boolean, because if return boolean False, argument is not printed\n",
                    "id": "#trimmomatic.cwl/trigger"
                },
                {
                    "type": "string",
                    "default": "/usr/share/java/trimmomatic.jar",
                    "inputBinding": {
                        "position": 7,
                        "prefix": "-jar"
                    },
                    "id": "#trimmomatic.cwl/trimmomatic_jar_path"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "prefix": "-validatePairs",
                        "position": 10
                    },
                    "doc": "Run -validatePairs. No official documentation\n",
                    "id": "#trimmomatic.cwl/validate_pairs"
                }
            ],
            "outputs": [
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputBinding": {
                        "glob": "${\n  if (inputs.lib_type==\"PE\"){\n    return inputs.trigger?default_output_filename(inputs.fastq_file_downstream,'.trimmed.fastq'):inputs.fastq_file_downstream.basename;\n  }\n  return null;\n}\n"
                    },
                    "id": "#trimmomatic.cwl/downstream_trimmed_file"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputBinding": {
                        "glob": "${\n  return inputs.lib_type==\"PE\"?default_output_filename(inputs.fastq_file_downstream, '.unpaired.trimmed.fastq'):null;\n}\n"
                    },
                    "id": "#trimmomatic.cwl/downstream_trimmed_unpaired_file"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputBinding": {
                        "glob": "$(inputs.log_filename)"
                    },
                    "doc": "Trimmomatic Log file.\n",
                    "id": "#trimmomatic.cwl/log_file"
                },
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "${\n  return inputs.trigger?default_output_filename(inputs.fastq_file_upstream, '.trimmed.fastq'):inputs.fastq_file_upstream.basename;\n}\n"
                    },
                    "id": "#trimmomatic.cwl/upstream_trimmed_file"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputBinding": {
                        "glob": "${\n  return inputs.lib_type==\"PE\"?default_output_filename(inputs.fastq_file_upstream, '.unpaired.trimmed.fastq'):null;\n}\n"
                    },
                    "id": "#trimmomatic.cwl/upstream_trimmed_unpaired_file"
                }
            ],
            "baseCommand": [
                "bash",
                "-c"
            ],
            "arguments": [
                {
                    "valueFrom": "$(default_output_filename(inputs.fastq_file_upstream, '.trimmed.fastq'))",
                    "position": 15
                },
                {
                    "valueFrom": "$(inputs.lib_type==\"PE\"?default_output_filename(inputs.fastq_file_upstream, '.trimmed.unpaired.fastq'):null)",
                    "position": 16
                },
                {
                    "valueFrom": "$(inputs.lib_type==\"PE\"?default_output_filename(inputs.fastq_file_downstream, '.trimmed.fastq'):null)",
                    "position": 17
                },
                {
                    "valueFrom": "$(inputs.lib_type==\"PE\"?default_output_filename(inputs.fastq_file_downstream, '.trimmed.unpaired.fastq'):null)",
                    "position": 18
                },
                {
                    "valueFrom": "$(\"ILLUMINACLIP:\" + inputs.adapters_file.path + \":\"+ inputs.illuminaclip_step_param)",
                    "position": 100
                }
            ],
            "doc": "Tool runs trimmomatic with ILLUMINACLIP step by default.\n\n`-basein` and `-baseout` inputs are skipped.\n\nIf set `lib_type` to `PE`, both of the inputs `fastq_file_upstream` and `fastq_file_downstream` shoul be provided.\n\nIf input `trigger` is set to `true` or isn't set at all (`true` is used by default), run `trimmomatic` and return\nFASTQ file[s] with trimmed adapters, alongside with the uppaired reads FASTQ files (if `lib_type` is set to `PE` and\nsuch files are present after running `trimmomatic`)\nIf input `trigger` is set to `false`, return unchanged `fastq_file_upstream` and `fastq_file_downstream`, previously\nstaged into output directory.\n\nBefore execution `baseCommand`, `fastq_file_upstream` and `fastq_file_downstream` (if provided) are staged into directory\nset as docker parameter `--workdir` (tool's output directory), using `InitialWorkDirRequirement`. They are mount\nto docker container with `ro` mode as part of `--workdir`, because all generated files will have `trimmed` suffix\nin their names, so the staged files will not be overwritten.\n\nTrigger logic is implemented in a bash scripts set by default as `bash_script` input. If the first argument $0 (which is\n`trigger` input) is true, run `trimmomatic` with the rest of the arguments. If $0 is not true, skip `trimmomatic` and\nreturn `fastq_file_upstream` and `fastq_file_downstream` (if provided) staged into output directory.\n\nInput `trigger` is Boolean, but returns String, because of `valueFrom` field. The `valueFrom` is used, because if `trigger`\nis false, cwl-runner doesn't append this argument at all to the the `baseCommand` - new feature of CWL v1.0.2. Alternatively,\n`prefix` field could be used, but it causes changing in script logic.\n\n`default_output_name` function is used for generating output filename based on `input_file.basename` and provided\nextension.\n",
            "id": "#trimmomatic.cwl",
            "http://schema.org/mainEntity": {
                "class": "http://schema.org/SoftwareSourceCode",
                "id": "#trimmomatic-metadata.yaml",
                "http://schema.org/name": "trimmomatic",
                "http://schema.org/about": "Trimmomatic is a fast, multithreaded command line tool that can be used to trim and crop\nIllumina (FASTQ) data as well as to remove adapters. These adapters can pose a real problem\ndepending on the library preparation and downstream application.\n",
                "http://schema.org/url": "http://www.usadellab.org/cms/?page=trimmomatic",
                "http://schema.org/codeRepository": "http://www.usadellab.org/cms/uploads/supplementary/Trimmomatic/Trimmomatic-Src-0.35.zip",
                "http://schema.org/license": [
                    "https://opensource.org/licenses/GPL-3.0"
                ],
                "http://schema.org/targetProduct": {
                    "class": "http://schema.org/SoftwareApplication",
                    "http://schema.org/softwareVersion": "0.35",
                    "http://schema.org/applicationCategory": "command line tool"
                },
                "http://schema.org/programmingLanguage": "Java",
                "http://schema.org/creator": [
                    {
                        "class": "http://schema.org/Organization",
                        "http://schema.org/name": "USADELLAB",
                        "http://schema.org/member": [
                            {
                                "class": "http://schema.org/Person",
                                "http://schema.org/name": "Bolger AM"
                            },
                            {
                                "class": "http://schema.org/Person",
                                "http://schema.org/name": "Lohse M"
                            },
                            {
                                "class": "http://schema.org/Person",
                                "http://schema.org/name": "Usadel B"
                            }
                        ]
                    }
                ]
            },
            "http://schema.org/name": "trimmomatic",
            "http://schema.org/downloadUrl": "https://raw.githubusercontent.com/Barski-lab/workflows/master/tools/trimmomatic.cwl",
            "http://schema.org/codeRepository": "https://github.com/Barski-lab/workflows",
            "http://schema.org/license": "http://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/isPartOf": {
                "class": "http://schema.org/CreativeWork",
                "http://schema.org/name": "Common Workflow Language",
                "http://schema.org/url": "http://commonwl.org/"
            },
            "http://schema.org/creator": [
                {
                    "class": "http://schema.org/Organization",
                    "http://schema.org/legalName": "Cincinnati Children's Hospital Medical Center",
                    "http://schema.org/location": [
                        {
                            "class": "http://schema.org/PostalAddress",
                            "http://schema.org/addressCountry": "USA",
                            "http://schema.org/addressLocality": "Cincinnati",
                            "http://schema.org/addressRegion": "OH",
                            "http://schema.org/postalCode": "45229",
                            "http://schema.org/streetAddress": "3333 Burnet Ave",
                            "http://schema.org/telephone": "+1(513)636-4200"
                        }
                    ],
                    "http://schema.org/logo": "https://www.cincinnatichildrens.org/-/media/cincinnati%20childrens/global%20shared/childrens-logo-new.png",
                    "http://schema.org/department": [
                        {
                            "class": "http://schema.org/Organization",
                            "http://schema.org/legalName": "Allergy and Immunology",
                            "http://schema.org/department": [
                                {
                                    "class": "http://schema.org/Organization",
                                    "http://schema.org/legalName": "Barski Research Lab",
                                    "http://schema.org/member": [
                                        {
                                            "class": "http://schema.org/Person",
                                            "http://schema.org/name": "Michael Kotliar",
                                            "http://schema.org/email": "mailto:misha.kotliar@gmail.com",
                                            "http://schema.org/sameAs": [
                                                {
                                                    "$import": "#0000-0002-6486-3898"
                                                }
                                            ]
                                        }
                                    ]
                                }
                            ]
                        }
                    ]
                }
            ],
            "http://schema.org/about": "Usage:\n       PE [-threads <threads>] [-phred33|-phred64] [-trimlog <trimLogFile>] [-quiet] [-validatePairs] [-basein <inputBase> | <inputFile1> <inputFile2>] [-baseout <outputBase> | <outputFile1P> <outputFile1U> <outputFile2P> <outputFile2U>] <trimmer1>...\n   or:\n       SE [-threads <threads>] [-phred33|-phred64] [-trimlog <trimLogFile>] [-quiet] <inputFile> <outputFile> <trimmer1>...\n"
        },
        {
            "class": "CommandLineTool",
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement",
                    "expressionLib": [
                        "var default_output_filename = function() { let basename = inputs.bedgraph_file.location.split('/').slice(-1)[0]; let root = basename.split('.').slice(0,-1).join('.'); let ext = \".bigWig\"; return (root == \"\")?basename+ext:root+ext; };"
                    ]
                }
            ],
            "hints": [
                {
                    "class": "DockerRequirement",
                    "dockerPull": "biowardrobe2/ucscuserapps:v358"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 10
                    },
                    "doc": "Four column bedGraph file: <chrom> <start> <end> <value>\n",
                    "id": "#ucsc-bedgraphtobigwig.cwl/bedgraph_file"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "separate": false,
                        "position": 7,
                        "prefix": "-blockSize="
                    },
                    "doc": "Number of items to bundle in r-tree.  Default 256\n",
                    "id": "#ucsc-bedgraphtobigwig.cwl/block_size"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 11
                    },
                    "doc": "Two-column chromosome length file: <chromosome name> <size in bases>\n",
                    "id": "#ucsc-bedgraphtobigwig.cwl/chrom_length_file"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "separate": false,
                        "position": 6,
                        "prefix": "-itemsPerSlot="
                    },
                    "doc": "Number of data points bundled at lowest level. Default 1024\n",
                    "id": "#ucsc-bedgraphtobigwig.cwl/items_per_slot"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "inputBinding": {
                        "position": 12,
                        "valueFrom": "${\n    if (self == \"\"){\n      return default_output_filename();\n    } else {\n      return self;\n    }\n}\n"
                    },
                    "default": "",
                    "doc": "If set, writes the output bigWig file to output_filename,\notherwise generates filename from default_output_filename()\n",
                    "id": "#ucsc-bedgraphtobigwig.cwl/output_filename"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 5,
                        "prefix": "-unc"
                    },
                    "doc": "Disable compression\n",
                    "id": "#ucsc-bedgraphtobigwig.cwl/unc"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "${\n    if (inputs.output_filename == \"\"){\n      return default_output_filename();\n    } else {\n      return inputs.output_filename;\n    }\n}\n"
                    },
                    "id": "#ucsc-bedgraphtobigwig.cwl/bigwig_file"
                }
            ],
            "baseCommand": [
                "bedGraphToBigWig"
            ],
            "doc": "Tool converts bedGraph to bigWig file.\n\n`default_output_filename` function returns filename for generated bigWig if `output_filename` is not provided.\nDefault filename is generated on the base of `bedgraph_file` basename with the updated to `*.bigWig` extension.\n",
            "id": "#ucsc-bedgraphtobigwig.cwl",
            "http://schema.org/mainEntity": {
                "class": "http://schema.org/SoftwareSourceCode",
                "id": "#ucsc-metadata.yaml",
                "http://schema.org/name": "UCSC userApps",
                "http://schema.org/about": "UCSC genome browser bioinformatic utilities\n",
                "http://schema.org/url": "https://genome.ucsc.edu/util.html",
                "http://schema.org/targetProduct": {
                    "class": "http://schema.org/SoftwareApplication",
                    "http://schema.org/softwareVersion": "v358",
                    "http://schema.org/applicationCategory": "commandline tool",
                    "http://schema.org/downloadURL": "http://hgdownload.cse.ucsc.edu/admin/exe/userApps.v358.src.tgz"
                },
                "http://schema.org/programmingLanguage": "C++",
                "http://schema.org/license": [
                    "https://opensource.org/licenses/GPL-3.0"
                ]
            },
            "http://schema.org/name": "ucsc-bedgraphtobigwig",
            "http://schema.org/downloadUrl": "https://raw.githubusercontent.com/Barski-lab/workflows/master/tools/ucsc-bedgraphtobigwig.cwl",
            "http://schema.org/codeRepository": "https://github.com/Barski-lab/workflows",
            "http://schema.org/license": "http://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/isPartOf": {
                "class": "http://schema.org/CreativeWork",
                "http://schema.org/name": "Common Workflow Language",
                "http://schema.org/url": "http://commonwl.org/"
            },
            "http://schema.org/creator": [
                {
                    "class": "http://schema.org/Organization",
                    "http://schema.org/legalName": "Cincinnati Children's Hospital Medical Center",
                    "http://schema.org/location": [
                        {
                            "class": "http://schema.org/PostalAddress",
                            "http://schema.org/addressCountry": "USA",
                            "http://schema.org/addressLocality": "Cincinnati",
                            "http://schema.org/addressRegion": "OH",
                            "http://schema.org/postalCode": "45229",
                            "http://schema.org/streetAddress": "3333 Burnet Ave",
                            "http://schema.org/telephone": "+1(513)636-4200"
                        }
                    ],
                    "http://schema.org/logo": "https://www.cincinnatichildrens.org/-/media/cincinnati%20childrens/global%20shared/childrens-logo-new.png",
                    "http://schema.org/department": [
                        {
                            "class": "http://schema.org/Organization",
                            "http://schema.org/legalName": "Allergy and Immunology",
                            "http://schema.org/department": [
                                {
                                    "class": "http://schema.org/Organization",
                                    "http://schema.org/legalName": "Barski Research Lab",
                                    "http://schema.org/member": [
                                        {
                                            "class": "http://schema.org/Person",
                                            "http://schema.org/name": "Andrey Kartashov",
                                            "http://schema.org/email": "mailto:Andrey.Kartashov@cchmc.org",
                                            "http://schema.org/sameAs": [
                                                {
                                                    "$import": "#0000-0001-9102-5681"
                                                }
                                            ]
                                        },
                                        {
                                            "class": "http://schema.org/Person",
                                            "http://schema.org/name": "Michael Kotliar",
                                            "http://schema.org/email": "mailto:misha.kotliar@gmail.com",
                                            "http://schema.org/sameAs": [
                                                {
                                                    "$import": "#0000-0002-6486-3898"
                                                }
                                            ]
                                        }
                                    ]
                                }
                            ]
                        }
                    ]
                }
            ],
            "http://schema.org/about": "usage:\n   bedGraphToBigWig in.bedGraph chrom.sizes out.bw\nwhere in.bedGraph is a four column file in the format:\n      <chrom> <start> <end> <value>\nand chrom.sizes is a two-column file/URL: <chromosome name> <size in bases>\nand out.bw is the output indexed big wig file.\nIf the assembly <db> is hosted by UCSC, chrom.sizes can be a URL like\n  http://hgdownload.cse.ucsc.edu/goldenPath/<db>/bigZips/<db>.chrom.sizes\nor you may use the script fetchChromSizes to download the chrom.sizes file.\nIf not hosted by UCSC, a chrom.sizes file can be generated by running\ntwoBitInfo on the assembly .2bit file.\nThe input bedGraph file must be sorted, use the unix sort command:\n  sort -k1,1 -k2,2n unsorted.bedGraph > sorted.bedGraph\noptions:\n   -blockSize=N - Number of items to bundle in r-tree.  Default 256\n   -itemsPerSlot=N - Number of data points bundled at lowest level. Default 1024\n   -unc - If set, do not use compression.\n"
        },
        {
            "class": "Workflow",
            "requirements": [
                {
                    "class": "SubworkflowFeatureRequirement"
                },
                {
                    "class": "StepInputExpressionRequirement"
                },
                {
                    "class": "MultipleInputFeatureRequirement"
                },
                {
                    "class": "InlineJavascriptRequirement",
                    "expressionLib": [
                        "var default_output_name = function(named_input, ext, segment) { ext = ext || \"\"; segment = segment || 1; if (Array.isArray(named_input) && named_input.length > 0){ return named_input[0].location.split('/').slice(-1)[0].split('.').slice(0,segment).join('.')+ext; } else { return named_input.location.split('/').slice(-1)[0].split('.').slice(0,segment).join('.')+ext; } };"
                    ]
                }
            ],
            "inputs": [
                {
                    "type": "Directory",
                    "label": "BowTie Ribosomal Indices",
                    "doc": "Path to Bowtie generated indices for ribosomal FASTA",
                    "id": "#main/bowtie_indices_folder"
                },
                {
                    "type": "File",
                    "label": "Adapters FASTA file",
                    "format": "http://edamontology.org/format_1929",
                    "doc": "Adapters FASTA file to be used by Trimmomatic",
                    "id": "#main/fasta_file_adapters"
                },
                {
                    "type": "File",
                    "label": "FASTQ downstream input file",
                    "format": "http://edamontology.org/format_1930",
                    "doc": "Downstream reads data in a FASTQ format, received after paired end sequencing",
                    "id": "#main/fastq_file_downstream"
                },
                {
                    "type": "File",
                    "label": "FASTQ upstream input file",
                    "format": "http://edamontology.org/format_1930",
                    "doc": "Upstream reads data in a FASTQ format, received after paired end sequencing",
                    "id": "#main/fastq_file_upstream"
                },
                {
                    "type": "Directory",
                    "label": "RSEM indices folder",
                    "doc": "Path to RSEM indices generated with BowTie2",
                    "id": "#main/rsem_indices_folder"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "default": 2,
                    "label": "Number of threads",
                    "doc": "Number of threads for those steps that support multithreading",
                    "id": "#main/threads"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "format": "http://edamontology.org/format_2572",
                    "label": "Coordinate sorted BAM alignment file (+index BAI)",
                    "doc": "Coordinate sorted BAM file and BAI index file",
                    "outputSource": "#main/rename_rsem_bambai_pair/target_file",
                    "id": "#main/bambai_pair"
                },
                {
                    "type": "File",
                    "format": "http://edamontology.org/format_3006",
                    "label": "BigWig file",
                    "doc": "Generated BigWig file",
                    "outputSource": "#main/bam_to_bigwig/bigwig_file",
                    "id": "#main/bigwig_file"
                },
                {
                    "type": "File",
                    "format": "http://edamontology.org/format_3752",
                    "label": "Biowardrobe compatible isoforms expression file",
                    "doc": "Biowardrobe compatible isoforms expression file",
                    "outputSource": "#main/make_biowardrobe_isoforms/biowardrobe_isoforms_file",
                    "id": "#main/biowardrobe_isoforms_file"
                },
                {
                    "type": "File",
                    "format": "http://edamontology.org/format_2330",
                    "label": "Ribo Bowtie alignment log",
                    "doc": "Ribo Bowtie alignment log file. Mostly for debug purposes",
                    "outputSource": "#main/ribo_bowtie_aligner/log_file",
                    "id": "#main/bowtie_log"
                },
                {
                    "type": "File",
                    "format": "http://edamontology.org/format_2330",
                    "label": "FASTQ downstream statistics",
                    "doc": "fastx_quality_stats generated downstream FASTQ quality statistics file",
                    "outputSource": "#main/fastx_quality_stats_downstream/statistics_file",
                    "id": "#main/fastx_statistics_downstream"
                },
                {
                    "type": "File",
                    "format": "http://edamontology.org/format_2330",
                    "label": "FASTQ upstream statistics",
                    "doc": "fastx_quality_stats generated upstream FASTQ quality statistics file",
                    "outputSource": "#main/fastx_quality_stats_upstream/statistics_file",
                    "id": "#main/fastx_statistics_upstream"
                },
                {
                    "type": "File",
                    "label": "RSEM & Bowtie combined log",
                    "format": "http://edamontology.org/format_2330",
                    "doc": "Mapping statistics from RSEM & Bowtie logs",
                    "outputSource": "#main/get_stat/output_file",
                    "id": "#main/get_stat_log"
                },
                {
                    "type": "File",
                    "format": "http://edamontology.org/format_3475",
                    "label": "RSEM genes expression file",
                    "doc": "RSEM genes expression file",
                    "outputSource": "#main/rename_rsem_genes_file/target_file",
                    "id": "#main/rsem_genes_file"
                },
                {
                    "type": "File",
                    "format": "http://edamontology.org/format_3475",
                    "label": "RSEM isoforms expression file",
                    "doc": "RSEM isoforms expression file",
                    "outputSource": "#main/rename_rsem_isoforms_file/target_file",
                    "id": "#main/rsem_isoforms_file"
                },
                {
                    "type": "Directory",
                    "label": "RSEM alignment statistics",
                    "doc": "RSEM generated statistics folder. Mostly for debug purposes",
                    "outputSource": "#main/rsem_calculate_expression/stat_folder",
                    "id": "#main/rsem_stat_folder"
                }
            ],
            "steps": [
                {
                    "run": "#bam-bedgraph-bigwig.cwl",
                    "in": [
                        {
                            "source": "#main/rename_rsem_bambai_pair/target_file",
                            "id": "#main/bam_to_bigwig/bam_file"
                        },
                        {
                            "source": "#main/get_chr_length_file/selected_file",
                            "id": "#main/bam_to_bigwig/chrom_length_file"
                        },
                        {
                            "source": "#main/rsem_calculate_expression/mapped_reads_number",
                            "valueFrom": "$(self*2)",
                            "id": "#main/bam_to_bigwig/mapped_reads_number"
                        }
                    ],
                    "out": [
                        "#main/bam_to_bigwig/bigwig_file"
                    ],
                    "id": "#main/bam_to_bigwig"
                },
                {
                    "run": "#extract-fastq.cwl",
                    "in": [
                        {
                            "source": "#main/fastq_file_downstream",
                            "id": "#main/extract_fastq_downstream/compressed_file"
                        }
                    ],
                    "out": [
                        "#main/extract_fastq_downstream/fastq_file"
                    ],
                    "id": "#main/extract_fastq_downstream"
                },
                {
                    "run": "#extract-fastq.cwl",
                    "in": [
                        {
                            "source": "#main/fastq_file_upstream",
                            "id": "#main/extract_fastq_upstream/compressed_file"
                        }
                    ],
                    "out": [
                        "#main/extract_fastq_upstream/fastq_file"
                    ],
                    "id": "#main/extract_fastq_upstream"
                },
                {
                    "run": "#fastqc-results-trigger.cwl",
                    "in": [
                        {
                            "source": "#main/fastqc_stats_downstream/summary_file",
                            "id": "#main/fastqc_results_trigger_downstream/summary_file"
                        }
                    ],
                    "out": [
                        "#main/fastqc_results_trigger_downstream/trigger"
                    ],
                    "id": "#main/fastqc_results_trigger_downstream"
                },
                {
                    "run": "#fastqc-results-trigger.cwl",
                    "in": [
                        {
                            "source": "#main/fastqc_stats_upstream/summary_file",
                            "id": "#main/fastqc_results_trigger_upstream/summary_file"
                        }
                    ],
                    "out": [
                        "#main/fastqc_results_trigger_upstream/trigger"
                    ],
                    "id": "#main/fastqc_results_trigger_upstream"
                },
                {
                    "run": "#fastqc.cwl",
                    "in": [
                        {
                            "source": "#main/extract_fastq_downstream/fastq_file",
                            "id": "#main/fastqc_stats_downstream/fastq_file"
                        }
                    ],
                    "out": [
                        "#main/fastqc_stats_downstream/summary_file"
                    ],
                    "id": "#main/fastqc_stats_downstream"
                },
                {
                    "run": "#fastqc.cwl",
                    "in": [
                        {
                            "source": "#main/extract_fastq_upstream/fastq_file",
                            "id": "#main/fastqc_stats_upstream/fastq_file"
                        }
                    ],
                    "out": [
                        "#main/fastqc_stats_upstream/summary_file"
                    ],
                    "id": "#main/fastqc_stats_upstream"
                },
                {
                    "run": "#fastx-quality-stats.cwl",
                    "in": [
                        {
                            "source": "#main/extract_fastq_downstream/fastq_file",
                            "id": "#main/fastx_quality_stats_downstream/input_file"
                        }
                    ],
                    "out": [
                        "#main/fastx_quality_stats_downstream/statistics_file"
                    ],
                    "id": "#main/fastx_quality_stats_downstream"
                },
                {
                    "run": "#fastx-quality-stats.cwl",
                    "in": [
                        {
                            "source": "#main/extract_fastq_upstream/fastq_file",
                            "id": "#main/fastx_quality_stats_upstream/input_file"
                        }
                    ],
                    "out": [
                        "#main/fastx_quality_stats_upstream/statistics_file"
                    ],
                    "id": "#main/fastx_quality_stats_upstream"
                },
                {
                    "run": "#get-file-by-name.cwl",
                    "in": [
                        {
                            "default": "ti$",
                            "id": "#main/get_annotation_file/basename_regex"
                        },
                        {
                            "source": "#main/rsem_indices_folder",
                            "id": "#main/get_annotation_file/input_files"
                        }
                    ],
                    "out": [
                        "#main/get_annotation_file/selected_file"
                    ],
                    "id": "#main/get_annotation_file"
                },
                {
                    "run": "#get-file-by-name.cwl",
                    "in": [
                        {
                            "default": "chrlist$",
                            "id": "#main/get_chr_length_file/basename_regex"
                        },
                        {
                            "source": "#main/rsem_indices_folder",
                            "id": "#main/get_chr_length_file/input_files"
                        }
                    ],
                    "out": [
                        "#main/get_chr_length_file/selected_file"
                    ],
                    "id": "#main/get_chr_length_file"
                },
                {
                    "run": "#custom-bash.cwl",
                    "in": [
                        {
                            "source": "#main/rsem_calculate_expression/isoform_results_file",
                            "id": "#main/get_stat/input_file"
                        },
                        {
                            "source": [
                                "#main/rsem_calculate_expression/total_reads_number",
                                "#main/rsem_calculate_expression/mapped_reads_number",
                                "#main/ribo_bowtie_aligner/mapped_reads_number",
                                "#main/rsem_calculate_expression/multimapped_reads_number",
                                "#main/fastq_file_upstream"
                            ],
                            "valueFrom": "${\n  self[4] = default_output_name(self[4], \".stat\");\n  return self.map(String);\n}\n",
                            "id": "#main/get_stat/param"
                        },
                        {
                            "default": "echo -n $1 $2 $3 $4 `cat $0 | cut -f 5 | grep -v expected_count | awk '{sum+=$1} END {print int(sum)}'` > $5",
                            "id": "#main/get_stat/script"
                        }
                    ],
                    "out": [
                        "#main/get_stat/output_file"
                    ],
                    "id": "#main/get_stat"
                },
                {
                    "run": "#python-make-biowardrobe-isoforms.cwl",
                    "in": [
                        {
                            "source": "#main/get_annotation_file/selected_file",
                            "id": "#main/make_biowardrobe_isoforms/rsem_annotation_file"
                        },
                        {
                            "source": "#main/rename_rsem_isoforms_file/target_file",
                            "id": "#main/make_biowardrobe_isoforms/rsem_isoforms_file"
                        }
                    ],
                    "out": [
                        "#main/make_biowardrobe_isoforms/biowardrobe_isoforms_file"
                    ],
                    "id": "#main/make_biowardrobe_isoforms"
                },
                {
                    "run": "#rename.cwl",
                    "in": [
                        {
                            "source": "#main/rsem_calculate_expression/genome_sorted_bam_bai_pair",
                            "id": "#main/rename_rsem_bambai_pair/source_file"
                        },
                        {
                            "source": "#main/fastq_file_upstream",
                            "valueFrom": "$(default_output_name(self, \".bam\"))",
                            "id": "#main/rename_rsem_bambai_pair/target_filename"
                        }
                    ],
                    "out": [
                        "#main/rename_rsem_bambai_pair/target_file"
                    ],
                    "id": "#main/rename_rsem_bambai_pair"
                },
                {
                    "run": "#rename.cwl",
                    "in": [
                        {
                            "source": "#main/rsem_calculate_expression/gene_results_file",
                            "id": "#main/rename_rsem_genes_file/source_file"
                        },
                        {
                            "source": "#main/fastq_file_upstream",
                            "valueFrom": "$(default_output_name(self, \".genes.tsv\"))",
                            "id": "#main/rename_rsem_genes_file/target_filename"
                        }
                    ],
                    "out": [
                        "#main/rename_rsem_genes_file/target_file"
                    ],
                    "id": "#main/rename_rsem_genes_file"
                },
                {
                    "run": "#rename.cwl",
                    "in": [
                        {
                            "source": "#main/rsem_calculate_expression/isoform_results_file",
                            "id": "#main/rename_rsem_isoforms_file/source_file"
                        },
                        {
                            "source": "#main/fastq_file_upstream",
                            "valueFrom": "$(default_output_name(self, \".isoforms.tsv\"))",
                            "id": "#main/rename_rsem_isoforms_file/target_filename"
                        }
                    ],
                    "out": [
                        "#main/rename_rsem_isoforms_file/target_file"
                    ],
                    "id": "#main/rename_rsem_isoforms_file"
                },
                {
                    "run": "#bowtie-alignreads.cwl",
                    "in": [
                        {
                            "source": "#main/trim_adapters/downstream_trimmed_file",
                            "id": "#main/ribo_bowtie_aligner/downstream_filelist"
                        },
                        {
                            "source": "#main/bowtie_indices_folder",
                            "id": "#main/ribo_bowtie_aligner/indices_folder"
                        },
                        {
                            "source": "#main/fastq_file_upstream",
                            "valueFrom": "$(default_output_name(self, \".txt\"))",
                            "id": "#main/ribo_bowtie_aligner/output_filename"
                        },
                        {
                            "source": "#main/threads",
                            "id": "#main/ribo_bowtie_aligner/threads"
                        },
                        {
                            "source": "#main/trim_adapters/upstream_trimmed_file",
                            "id": "#main/ribo_bowtie_aligner/upstream_filelist"
                        },
                        {
                            "default": 3,
                            "id": "#main/ribo_bowtie_aligner/v"
                        }
                    ],
                    "out": [
                        "#main/ribo_bowtie_aligner/mapped_reads_number",
                        "#main/ribo_bowtie_aligner/log_file"
                    ],
                    "id": "#main/ribo_bowtie_aligner"
                },
                {
                    "run": "#rsem-calculate-expression.cwl",
                    "in": [
                        {
                            "default": true,
                            "id": "#main/rsem_calculate_expression/bowtie2"
                        },
                        {
                            "source": "#main/trim_adapters/downstream_trimmed_file",
                            "id": "#main/rsem_calculate_expression/downstream_read_file"
                        },
                        {
                            "source": "#main/rsem_indices_folder",
                            "id": "#main/rsem_calculate_expression/indices_folder"
                        },
                        {
                            "default": true,
                            "id": "#main/rsem_calculate_expression/output_genome_bam"
                        },
                        {
                            "default": true,
                            "id": "#main/rsem_calculate_expression/sort_bam_by_coordinate"
                        },
                        {
                            "source": "#main/threads",
                            "id": "#main/rsem_calculate_expression/threads"
                        },
                        {
                            "source": "#main/trim_adapters/upstream_trimmed_file",
                            "id": "#main/rsem_calculate_expression/upstream_read_file"
                        }
                    ],
                    "out": [
                        "#main/rsem_calculate_expression/isoform_results_file",
                        "#main/rsem_calculate_expression/gene_results_file",
                        "#main/rsem_calculate_expression/genome_sorted_bam_bai_pair",
                        "#main/rsem_calculate_expression/stat_folder",
                        "#main/rsem_calculate_expression/total_reads_number",
                        "#main/rsem_calculate_expression/mapped_reads_number",
                        "#main/rsem_calculate_expression/multimapped_reads_number"
                    ],
                    "id": "#main/rsem_calculate_expression"
                },
                {
                    "run": "#trimmomatic.cwl",
                    "in": [
                        {
                            "source": "#main/fasta_file_adapters",
                            "id": "#main/trim_adapters/adapters_file"
                        },
                        {
                            "source": "#main/extract_fastq_downstream/fastq_file",
                            "id": "#main/trim_adapters/fastq_file_downstream"
                        },
                        {
                            "source": "#main/extract_fastq_upstream/fastq_file",
                            "id": "#main/trim_adapters/fastq_file_upstream"
                        },
                        {
                            "default": "2:30:15",
                            "id": "#main/trim_adapters/illuminaclip_step_param"
                        },
                        {
                            "default": "PE",
                            "id": "#main/trim_adapters/lib_type"
                        },
                        {
                            "source": "#main/threads",
                            "id": "#main/trim_adapters/threads"
                        },
                        {
                            "source": [
                                "#main/fastqc_results_trigger_upstream/trigger",
                                "#main/fastqc_results_trigger_downstream/trigger"
                            ],
                            "valueFrom": "${\n    return self[0] && self[1];\n}\n",
                            "id": "#main/trim_adapters/trigger"
                        }
                    ],
                    "out": [
                        "#main/trim_adapters/upstream_trimmed_file",
                        "#main/trim_adapters/downstream_trimmed_file"
                    ],
                    "id": "#main/trim_adapters"
                }
            ],
            "doc": "XenBase workflow for analysing RNA-Seq paired-end data\n",
            "id": "#main",
            "http://schema.org/name": "xenbase-rnaseq-pe",
            "http://schema.org/downloadUrl": "https://raw.githubusercontent.com/Barski-lab/workflows/master/workflows/xenbase-rnaseq-pe.cwl",
            "http://schema.org/codeRepository": "https://github.com/Barski-lab/workflows",
            "http://schema.org/license": "http://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/isPartOf": {
                "class": "http://schema.org/CreativeWork",
                "http://schema.org/name": "Common Workflow Language",
                "http://schema.org/url": "http://commonwl.org/"
            },
            "http://schema.org/creator": [
                {
                    "class": "http://schema.org/Organization",
                    "http://schema.org/legalName": "Cincinnati Children's Hospital Medical Center",
                    "http://schema.org/location": [
                        {
                            "class": "http://schema.org/PostalAddress",
                            "http://schema.org/addressCountry": "USA",
                            "http://schema.org/addressLocality": "Cincinnati",
                            "http://schema.org/addressRegion": "OH",
                            "http://schema.org/postalCode": "45229",
                            "http://schema.org/streetAddress": "3333 Burnet Ave",
                            "http://schema.org/telephone": "+1(513)636-4200"
                        }
                    ],
                    "http://schema.org/logo": "https://www.cincinnatichildrens.org/-/media/cincinnati%20childrens/global%20shared/childrens-logo-new.png",
                    "http://schema.org/department": [
                        {
                            "class": "http://schema.org/Organization",
                            "http://schema.org/legalName": "Allergy and Immunology",
                            "http://schema.org/department": [
                                {
                                    "class": "http://schema.org/Organization",
                                    "http://schema.org/legalName": "Barski Research Lab",
                                    "http://schema.org/member": [
                                        {
                                            "class": "http://schema.org/Person",
                                            "http://schema.org/name": "Michael Kotliar",
                                            "http://schema.org/email": "mailto:misha.kotliar@gmail.com",
                                            "http://schema.org/sameAs": [
                                                {
                                                    "$import": "#0000-0002-6486-3898"
                                                }
                                            ]
                                        }
                                    ]
                                }
                            ]
                        }
                    ]
                }
            ],
            "http://schema.org/about": "1. Convert input SRA file into pair of upsrtream and downstream FASTQ files (run fastq-dump)\n2. Analyze quality of FASTQ files (run fastqc with each of the FASTQ files)\n3. If any of the following fields in fastqc generated report is marked as failed for at least one of input FASTQ files:\n      \"Per base sequence quality\",\n      \"Per sequence quality scores\",\n      \"Overrepresented sequences\",\n      \"Adapter Content\",\n  - trim adapters (run trimmomatic)\n4. Align original or trimmed FASTQ files to reference genome, calculate genes and isoforms expression (run RSEM)\n5. Count mapped reads number in sorted BAM file (run bamtools stats)\n6. Generate genome coverage BED file (run bedtools genomecov)\n7. Sort genearted BED file (run sort)\n8. Generate genome coverage bigWig file from BED file (run bedGraphToBigWig)"
        }
    ],
    "cwlVersion": "v1.0",
    "$schemas": [
        "http://schema.org/docs/schema_org_rdfa.html"
    ],
    "$namespaces": {
        "s": "http://schema.org/"
    }
}
